/******/ (function(modules) { // webpackBootstrap
/******/ 	// install a JSONP callback for chunk loading
/******/ 	function webpackJsonpCallback(data) {
/******/ 		var chunkIds = data[0];
/******/ 		var moreModules = data[1];
/******/ 		var executeModules = data[2];
/******/
/******/ 		// add "moreModules" to the modules object,
/******/ 		// then flag all "chunkIds" as loaded and fire callback
/******/ 		var moduleId, chunkId, i = 0, resolves = [];
/******/ 		for(;i < chunkIds.length; i++) {
/******/ 			chunkId = chunkIds[i];
/******/ 			if(Object.prototype.hasOwnProperty.call(installedChunks, chunkId) && installedChunks[chunkId]) {
/******/ 				resolves.push(installedChunks[chunkId][0]);
/******/ 			}
/******/ 			installedChunks[chunkId] = 0;
/******/ 		}
/******/ 		for(moduleId in moreModules) {
/******/ 			if(Object.prototype.hasOwnProperty.call(moreModules, moduleId)) {
/******/ 				modules[moduleId] = moreModules[moduleId];
/******/ 			}
/******/ 		}
/******/ 		if(parentJsonpFunction) parentJsonpFunction(data);
/******/
/******/ 		while(resolves.length) {
/******/ 			resolves.shift()();
/******/ 		}
/******/
/******/ 		// add entry modules from loaded chunk to deferred list
/******/ 		deferredModules.push.apply(deferredModules, executeModules || []);
/******/
/******/ 		// run deferred modules when all chunks ready
/******/ 		return checkDeferredModules();
/******/ 	};
/******/ 	function checkDeferredModules() {
/******/ 		var result;
/******/ 		for(var i = 0; i < deferredModules.length; i++) {
/******/ 			var deferredModule = deferredModules[i];
/******/ 			var fulfilled = true;
/******/ 			for(var j = 1; j < deferredModule.length; j++) {
/******/ 				var depId = deferredModule[j];
/******/ 				if(installedChunks[depId] !== 0) fulfilled = false;
/******/ 			}
/******/ 			if(fulfilled) {
/******/ 				deferredModules.splice(i--, 1);
/******/ 				result = __webpack_require__(__webpack_require__.s = deferredModule[0]);
/******/ 			}
/******/ 		}
/******/
/******/ 		return result;
/******/ 	}
/******/
/******/ 	// The module cache
/******/ 	var installedModules = {};
/******/
/******/ 	// object to store loaded and loading chunks
/******/ 	// undefined = chunk not loaded, null = chunk preloaded/prefetched
/******/ 	// Promise = chunk loading, 0 = chunk loaded
/******/ 	var installedChunks = {
/******/ 		"app": 0
/******/ 	};
/******/
/******/ 	var deferredModules = [];
/******/
/******/ 	// script path function
/******/ 	function jsonpScriptSrc(chunkId) {
/******/ 		return __webpack_require__.p + "js/" + ({"compareRuns~geoRun":"compareRuns~geoRun","compareRuns":"compareRuns","geoRun":"geoRun"}[chunkId]||chunkId) + ".js"
/******/ 	}
/******/
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/
/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId]) {
/******/ 			return installedModules[moduleId].exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			i: moduleId,
/******/ 			l: false,
/******/ 			exports: {}
/******/ 		};
/******/
/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/
/******/ 		// Flag the module as loaded
/******/ 		module.l = true;
/******/
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/
/******/ 	// This file contains only the entry chunk.
/******/ 	// The chunk loading function for additional chunks
/******/ 	__webpack_require__.e = function requireEnsure(chunkId) {
/******/ 		var promises = [];
/******/
/******/
/******/ 		// JSONP chunk loading for javascript
/******/
/******/ 		var installedChunkData = installedChunks[chunkId];
/******/ 		if(installedChunkData !== 0) { // 0 means "already installed".
/******/
/******/ 			// a Promise means "currently loading".
/******/ 			if(installedChunkData) {
/******/ 				promises.push(installedChunkData[2]);
/******/ 			} else {
/******/ 				// setup Promise in chunk cache
/******/ 				var promise = new Promise(function(resolve, reject) {
/******/ 					installedChunkData = installedChunks[chunkId] = [resolve, reject];
/******/ 				});
/******/ 				promises.push(installedChunkData[2] = promise);
/******/
/******/ 				// start chunk loading
/******/ 				var script = document.createElement('script');
/******/ 				var onScriptComplete;
/******/
/******/ 				script.charset = 'utf-8';
/******/ 				script.timeout = 120;
/******/ 				if (__webpack_require__.nc) {
/******/ 					script.setAttribute("nonce", __webpack_require__.nc);
/******/ 				}
/******/ 				script.src = jsonpScriptSrc(chunkId);
/******/
/******/ 				// create error before stack unwound to get useful stacktrace later
/******/ 				var error = new Error();
/******/ 				onScriptComplete = function (event) {
/******/ 					// avoid mem leaks in IE.
/******/ 					script.onerror = script.onload = null;
/******/ 					clearTimeout(timeout);
/******/ 					var chunk = installedChunks[chunkId];
/******/ 					if(chunk !== 0) {
/******/ 						if(chunk) {
/******/ 							var errorType = event && (event.type === 'load' ? 'missing' : event.type);
/******/ 							var realSrc = event && event.target && event.target.src;
/******/ 							error.message = 'Loading chunk ' + chunkId + ' failed.\n(' + errorType + ': ' + realSrc + ')';
/******/ 							error.name = 'ChunkLoadError';
/******/ 							error.type = errorType;
/******/ 							error.request = realSrc;
/******/ 							chunk[1](error);
/******/ 						}
/******/ 						installedChunks[chunkId] = undefined;
/******/ 					}
/******/ 				};
/******/ 				var timeout = setTimeout(function(){
/******/ 					onScriptComplete({ type: 'timeout', target: script });
/******/ 				}, 120000);
/******/ 				script.onerror = script.onload = onScriptComplete;
/******/ 				document.head.appendChild(script);
/******/ 			}
/******/ 		}
/******/ 		return Promise.all(promises);
/******/ 	};
/******/
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;
/******/
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;
/******/
/******/ 	// define getter function for harmony exports
/******/ 	__webpack_require__.d = function(exports, name, getter) {
/******/ 		if(!__webpack_require__.o(exports, name)) {
/******/ 			Object.defineProperty(exports, name, { enumerable: true, get: getter });
/******/ 		}
/******/ 	};
/******/
/******/ 	// define __esModule on exports
/******/ 	__webpack_require__.r = function(exports) {
/******/ 		if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 			Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 		}
/******/ 		Object.defineProperty(exports, '__esModule', { value: true });
/******/ 	};
/******/
/******/ 	// create a fake namespace object
/******/ 	// mode & 1: value is a module id, require it
/******/ 	// mode & 2: merge all properties of value into the ns
/******/ 	// mode & 4: return value when already ns object
/******/ 	// mode & 8|1: behave like require
/******/ 	__webpack_require__.t = function(value, mode) {
/******/ 		if(mode & 1) value = __webpack_require__(value);
/******/ 		if(mode & 8) return value;
/******/ 		if((mode & 4) && typeof value === 'object' && value && value.__esModule) return value;
/******/ 		var ns = Object.create(null);
/******/ 		__webpack_require__.r(ns);
/******/ 		Object.defineProperty(ns, 'default', { enumerable: true, value: value });
/******/ 		if(mode & 2 && typeof value != 'string') for(var key in value) __webpack_require__.d(ns, key, function(key) { return value[key]; }.bind(null, key));
/******/ 		return ns;
/******/ 	};
/******/
/******/ 	// getDefaultExport function for compatibility with non-harmony modules
/******/ 	__webpack_require__.n = function(module) {
/******/ 		var getter = module && module.__esModule ?
/******/ 			function getDefault() { return module['default']; } :
/******/ 			function getModuleExports() { return module; };
/******/ 		__webpack_require__.d(getter, 'a', getter);
/******/ 		return getter;
/******/ 	};
/******/
/******/ 	// Object.prototype.hasOwnProperty.call
/******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
/******/
/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "/";
/******/
/******/ 	// on error function for async loading
/******/ 	__webpack_require__.oe = function(err) { console.error(err); throw err; };
/******/
/******/ 	var jsonpArray = window["webpackJsonp"] = window["webpackJsonp"] || [];
/******/ 	var oldJsonpFunction = jsonpArray.push.bind(jsonpArray);
/******/ 	jsonpArray.push = webpackJsonpCallback;
/******/ 	jsonpArray = jsonpArray.slice();
/******/ 	for(var i = 0; i < jsonpArray.length; i++) webpackJsonpCallback(jsonpArray[i]);
/******/ 	var parentJsonpFunction = oldJsonpFunction;
/******/
/******/
/******/ 	// add entry module to deferred list
/******/ 	deferredModules.push([0,"chunk-vendors"]);
/******/ 	// run deferred modules when ready
/******/ 	return checkDeferredModules();
/******/ })
/************************************************************************/
/******/ ({

/***/ "./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/ts-loader/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/App.vue?vue&type=script&lang=ts":
/*!*******************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/cache-loader/dist/cjs.js??ref--13-0!./node_modules/babel-loader/lib!./node_modules/ts-loader??ref--13-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/App.vue?vue&type=script&lang=ts ***!
  \*******************************************************************************************************************************************************************************************************************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var core_js_modules_es_regexp_constructor_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! core-js/modules/es.regexp.constructor.js */ \"./node_modules/core-js/modules/es.regexp.constructor.js\");\n/* harmony import */ var core_js_modules_es_regexp_constructor_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_regexp_constructor_js__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var core_js_modules_es_regexp_exec_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! core-js/modules/es.regexp.exec.js */ \"./node_modules/core-js/modules/es.regexp.exec.js\");\n/* harmony import */ var core_js_modules_es_regexp_exec_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_regexp_exec_js__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var core_js_modules_es_regexp_to_string_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! core-js/modules/es.regexp.to-string.js */ \"./node_modules/core-js/modules/es.regexp.to-string.js\");\n/* harmony import */ var core_js_modules_es_regexp_to_string_js__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_regexp_to_string_js__WEBPACK_IMPORTED_MODULE_2__);\n/* harmony import */ var core_js_modules_es_string_replace_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! core-js/modules/es.string.replace.js */ \"./node_modules/core-js/modules/es.string.replace.js\");\n/* harmony import */ var core_js_modules_es_string_replace_js__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_string_replace_js__WEBPACK_IMPORTED_MODULE_3__);\n/* harmony import */ var _vue_runtime_core__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! @vue/runtime-core */ \"./node_modules/@vue/runtime-core/dist/runtime-core.esm-bundler.js\");\n/* harmony import */ var _api_API__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! @/api/API */ \"./src/api/API.ts\");\n/* harmony import */ var vue_router__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! vue-router */ \"./node_modules/vue-router/dist/vue-router.esm-bundler.js\");\n\n\n\n\n\n\n\n/* harmony default export */ __webpack_exports__[\"default\"] = (Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_4__[\"defineComponent\"])({\n  name: \"MainApp\",\n  components: {},\n  setup: function setup(props, context) {\n    var router = Object(vue_router__WEBPACK_IMPORTED_MODULE_6__[\"useRouter\"])();\n    var projectNames = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_4__[\"ref\"])([]);\n    var selectedProject = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_4__[\"ref\"])(\"\");\n    _api_API__WEBPACK_IMPORTED_MODULE_5__[\"allProjectNames\"]().then(function (r) {\n      console.log(\"All project names: \", r);\n      projectNames.value = r;\n\n      if (projectNames.value.length > 0) {\n        selectedProject.value = projectNames.value[0];\n      }\n    });\n    Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_4__[\"watch\"])(function () {\n      return selectedProject.value;\n    }, function (next, old) {\n      console.log(\"Old? \", old);\n      console.log(\"New? \", next);\n\n      if (old.length > 0) {\n        var regex = new RegExp(\"\".concat(old));\n        console.log(\"Regex? \", regex); // replace 'old' in the URL with 'new'\n\n        var current = router.currentRoute.value;\n        var currentPath = current.fullPath;\n        console.log(\"Current Path: \", currentPath);\n        var newPath = currentPath.replace(regex, next);\n        console.log(\"New Path: \", newPath);\n        router.push(newPath);\n      }\n    });\n    return {\n      selectedProject: selectedProject,\n      projectNames: projectNames\n    };\n  }\n}));\n\n//# sourceURL=webpack:///./src/App.vue?./node_modules/cache-loader/dist/cjs.js??ref--13-0!./node_modules/babel-loader/lib!./node_modules/ts-loader??ref--13-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/ts-loader/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/components/ChoroplethMap.vue?vue&type=script&lang=ts":
/*!****************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/cache-loader/dist/cjs.js??ref--13-0!./node_modules/babel-loader/lib!./node_modules/ts-loader??ref--13-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/components/ChoroplethMap.vue?vue&type=script&lang=ts ***!
  \****************************************************************************************************************************************************************************************************************************************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var core_js_modules_es_array_for_each_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! core-js/modules/es.array.for-each.js */ \"./node_modules/core-js/modules/es.array.for-each.js\");\n/* harmony import */ var core_js_modules_es_array_for_each_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_for_each_js__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var core_js_modules_es_array_map_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! core-js/modules/es.array.map.js */ \"./node_modules/core-js/modules/es.array.map.js\");\n/* harmony import */ var core_js_modules_es_array_map_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_map_js__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var core_js_modules_es_array_reduce_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! core-js/modules/es.array.reduce.js */ \"./node_modules/core-js/modules/es.array.reduce.js\");\n/* harmony import */ var core_js_modules_es_array_reduce_js__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_reduce_js__WEBPACK_IMPORTED_MODULE_2__);\n/* harmony import */ var core_js_modules_es_number_constructor_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! core-js/modules/es.number.constructor.js */ \"./node_modules/core-js/modules/es.number.constructor.js\");\n/* harmony import */ var core_js_modules_es_number_constructor_js__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_number_constructor_js__WEBPACK_IMPORTED_MODULE_3__);\n/* harmony import */ var core_js_modules_es_number_max_safe_integer_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! core-js/modules/es.number.max-safe-integer.js */ \"./node_modules/core-js/modules/es.number.max-safe-integer.js\");\n/* harmony import */ var core_js_modules_es_number_max_safe_integer_js__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_number_max_safe_integer_js__WEBPACK_IMPORTED_MODULE_4__);\n/* harmony import */ var core_js_modules_es_object_entries_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! core-js/modules/es.object.entries.js */ \"./node_modules/core-js/modules/es.object.entries.js\");\n/* harmony import */ var core_js_modules_es_object_entries_js__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_object_entries_js__WEBPACK_IMPORTED_MODULE_5__);\n/* harmony import */ var core_js_modules_es_object_keys_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! core-js/modules/es.object.keys.js */ \"./node_modules/core-js/modules/es.object.keys.js\");\n/* harmony import */ var core_js_modules_es_object_keys_js__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_object_keys_js__WEBPACK_IMPORTED_MODULE_6__);\n/* harmony import */ var core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! core-js/modules/es.object.to-string.js */ \"./node_modules/core-js/modules/es.object.to-string.js\");\n/* harmony import */ var core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_7__);\n/* harmony import */ var core_js_modules_web_dom_collections_for_each_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! core-js/modules/web.dom-collections.for-each.js */ \"./node_modules/core-js/modules/web.dom-collections.for-each.js\");\n/* harmony import */ var core_js_modules_web_dom_collections_for_each_js__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_web_dom_collections_for_each_js__WEBPACK_IMPORTED_MODULE_8__);\n/* harmony import */ var core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! core-js/modules/web.dom-collections.iterator.js */ \"./node_modules/core-js/modules/web.dom-collections.iterator.js\");\n/* harmony import */ var core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_9__);\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/slicedToArray */ \"./node_modules/@babel/runtime/helpers/esm/slicedToArray.js\");\n/* harmony import */ var _vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! @vue/runtime-core */ \"./node_modules/@vue/runtime-core/dist/runtime-core.esm-bundler.js\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! d3-geo */ \"./node_modules/d3-geo/src/index.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! d3-array */ \"./node_modules/d3-array/src/index.js\");\n/* harmony import */ var d3_scale__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! d3-scale */ \"./node_modules/d3-scale/src/index.js\");\n/* harmony import */ var d3_shape__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! d3-shape */ \"./node_modules/d3-shape/src/index.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n/* harmony default export */ __webpack_exports__[\"default\"] = (Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"defineComponent\"])({\n  name: \"ChoroplethMap\",\n  props: {\n    shapes: {\n      type: Object,\n      required: true\n    },\n    values: {\n      type: Object,\n      required: true\n    },\n    valueRange: {\n      type: Object,\n      default: null\n    },\n    sparklines: {\n      type: Object,\n      default: null\n    },\n    sparklineDotIndex: {\n      type: Number,\n      default: -1\n    },\n    projection: {\n      type: Function,\n      default: null\n    },\n    width: {\n      type: Number,\n      default: 400\n    },\n    height: {\n      type: Number,\n      default: 400\n    }\n  },\n  setup: function setup(props, ctx) {\n    // define reactive vars\n    var renderShapes = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"ref\"])([]);\n\n    var getPathgen = function getPathgen() {\n      var projection = props.projection;\n\n      if (projection == null) {\n        projection = Object(d3_geo__WEBPACK_IMPORTED_MODULE_12__[\"geoMercator\"])();\n        projection.fitSize([props.width, props.height], props.shapes);\n      }\n\n      return Object(d3_geo__WEBPACK_IMPORTED_MODULE_12__[\"geoPath\"])().projection(projection);\n    };\n\n    var maxRange = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"computed\"])(function () {\n      if (props.valueRange == null) {\n        return Object(d3_array__WEBPACK_IMPORTED_MODULE_13__[\"extent\"])(Object.entries(props.values).map(function (v) {\n          return v[1];\n        }));\n      } else {\n        return props.valueRange;\n      }\n    });\n    var colorScale = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"computed\"])(function () {\n      return Object(d3_scale__WEBPACK_IMPORTED_MODULE_14__[\"scaleLinear\"])().domain(maxRange.value).range([\"#ccc\", \"#333\"]);\n    });\n    var legendInfo = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"computed\"])(function () {\n      return maxRange.value.map(function (value) {\n        return {\n          value: value,\n          color: colorScale.value(value)\n        };\n      });\n    }); // convert props to renderShapes\n\n    var generateRenderData = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"computed\"])(function () {\n      return function () {\n        var pathGen = getPathgen();\n\n        var colorPerSite = function colorPerSite(SSID) {\n          var value = props.values[SSID];\n          return isNaN(value) ? colorScale.value.range()[0] : colorScale.value(value);\n        };\n\n        var features = props.shapes.features;\n        renderShapes.value = features.map(function (f) {\n          return {\n            f: f,\n            centroid: [0, 0],\n            // centroid: pathGen.centroid(f),\n            path: pathGen(f),\n            color: colorPerSite(f.properties.SSID)\n          };\n        });\n      };\n    });\n    var sparklineDots = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"computed\"])(function () {\n      var index = props.sparklineDotIndex;\n      var sparklineList = sparklineData.value;\n\n      if (index > -1 && sparklineList.length > 0) {\n        return sparklineList.reduce(function (collector, slData) {\n          if (slData.points.length > index) collector.push({\n            pos: slData.points[index],\n            centroid: slData.centroid,\n            lineOffset: slData.lineOffset\n          });\n          return collector;\n        }, []);\n      } else {\n        return [];\n      }\n    });\n    var sparklineData = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"computed\"])(function () {\n      if (props.sparklines == null) return [];\n      var features = props.shapes.features;\n      var allSparklines = Object.entries(props.sparklines);\n      var maxLength = 0;\n      var maxV = -Number.MAX_SAFE_INTEGER;\n      var minV = Number.MAX_SAFE_INTEGER;\n      allSparklines.map(function (_ref) {\n        var _ref2 = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_10__[\"default\"])(_ref, 2),\n            slID = _ref2[0],\n            sl = _ref2[1];\n\n        maxLength = sl.length > maxLength ? sl.length : maxLength;\n        sl.forEach(function (s) {\n          maxV = Math.max(maxV, s);\n          minV = Math.min(minV, s);\n        });\n      });\n      var slWidth = Math.floor(0.5 * props.width / Math.sqrt(Object.keys(props.values).length + 1));\n      var scaleX = Object(d3_scale__WEBPACK_IMPORTED_MODULE_14__[\"scaleLinear\"])().domain([0, maxLength - 1]).range([0, slWidth]);\n      var scaleY = Object(d3_scale__WEBPACK_IMPORTED_MODULE_14__[\"scaleLinear\"])().domain([minV, maxV]).range([20, 0]);\n      var lineGen = Object(d3_shape__WEBPACK_IMPORTED_MODULE_15__[\"line\"])().x(function (d, i) {\n        return d[0];\n      }).y(function (d, i) {\n        return d[1];\n      });\n      var pathGen = getPathgen();\n      var res = [];\n      features.forEach(function (f) {\n        var SSID = f.properties.SSID;\n        var sl = props.sparklines[SSID];\n\n        if (sl) {\n          var points = sl.map(function (d, i) {\n            return [scaleX(i), scaleY(d)];\n          });\n          var centroid = pathGen.centroid(f);\n          var lineOffset = [centroid[0] - slWidth / 2, centroid[1] - 10];\n          res.push({\n            centroid: centroid,\n            line: lineGen(points),\n            lineOffset: lineOffset,\n            points: points\n          });\n        }\n      });\n      return res;\n    });\n    Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"onMounted\"])(function () {\n      generateRenderData.value();\n    }); // should run less than \"computed\"\n\n    Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_11__[\"watch\"])(function () {\n      return [props.values, props.valueRange];\n    }, function () {\n      generateRenderData.value();\n    });\n    return {\n      renderShapes: renderShapes,\n      sparklineData: sparklineData,\n      legendInfo: legendInfo,\n      sparklineDots: sparklineDots\n    };\n  }\n}));\n\n//# sourceURL=webpack:///./src/components/ChoroplethMap.vue?./node_modules/cache-loader/dist/cjs.js??ref--13-0!./node_modules/babel-loader/lib!./node_modules/ts-loader??ref--13-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/ts-loader/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/components/HelloWorld.vue?vue&type=script&lang=ts":
/*!*************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/cache-loader/dist/cjs.js??ref--13-0!./node_modules/babel-loader/lib!./node_modules/ts-loader??ref--13-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/components/HelloWorld.vue?vue&type=script&lang=ts ***!
  \*************************************************************************************************************************************************************************************************************************************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var vue__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vue */ \"./node_modules/vue/dist/vue.runtime.esm-bundler.js\");\n\n/* harmony default export */ __webpack_exports__[\"default\"] = (Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"defineComponent\"])({\n  name: 'HelloWorld',\n  props: {\n    msg: String\n  }\n}));\n\n//# sourceURL=webpack:///./src/components/HelloWorld.vue?./node_modules/cache-loader/dist/cjs.js??ref--13-0!./node_modules/babel-loader/lib!./node_modules/ts-loader??ref--13-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/ts-loader/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/CompareGeos.vue?vue&type=script&lang=ts":
/*!*********************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/cache-loader/dist/cjs.js??ref--13-0!./node_modules/babel-loader/lib!./node_modules/ts-loader??ref--13-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/views/CompareGeos.vue?vue&type=script&lang=ts ***!
  \*********************************************************************************************************************************************************************************************************************************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var core_js_modules_es_array_concat_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! core-js/modules/es.array.concat.js */ \"./node_modules/core-js/modules/es.array.concat.js\");\n/* harmony import */ var core_js_modules_es_array_concat_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_concat_js__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var core_js_modules_es_array_filter_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! core-js/modules/es.array.filter.js */ \"./node_modules/core-js/modules/es.array.filter.js\");\n/* harmony import */ var core_js_modules_es_array_filter_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_filter_js__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var core_js_modules_es_array_for_each_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! core-js/modules/es.array.for-each.js */ \"./node_modules/core-js/modules/es.array.for-each.js\");\n/* harmony import */ var core_js_modules_es_array_for_each_js__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_for_each_js__WEBPACK_IMPORTED_MODULE_2__);\n/* harmony import */ var core_js_modules_es_array_map_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! core-js/modules/es.array.map.js */ \"./node_modules/core-js/modules/es.array.map.js\");\n/* harmony import */ var core_js_modules_es_array_map_js__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_map_js__WEBPACK_IMPORTED_MODULE_3__);\n/* harmony import */ var core_js_modules_es_array_slice_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! core-js/modules/es.array.slice.js */ \"./node_modules/core-js/modules/es.array.slice.js\");\n/* harmony import */ var core_js_modules_es_array_slice_js__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_slice_js__WEBPACK_IMPORTED_MODULE_4__);\n/* harmony import */ var core_js_modules_es_object_entries_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! core-js/modules/es.object.entries.js */ \"./node_modules/core-js/modules/es.object.entries.js\");\n/* harmony import */ var core_js_modules_es_object_entries_js__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_object_entries_js__WEBPACK_IMPORTED_MODULE_5__);\n/* harmony import */ var core_js_modules_es_object_keys_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! core-js/modules/es.object.keys.js */ \"./node_modules/core-js/modules/es.object.keys.js\");\n/* harmony import */ var core_js_modules_es_object_keys_js__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_object_keys_js__WEBPACK_IMPORTED_MODULE_6__);\n/* harmony import */ var core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! core-js/modules/es.object.to-string.js */ \"./node_modules/core-js/modules/es.object.to-string.js\");\n/* harmony import */ var core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_7__);\n/* harmony import */ var core_js_modules_es_set_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! core-js/modules/es.set.js */ \"./node_modules/core-js/modules/es.set.js\");\n/* harmony import */ var core_js_modules_es_set_js__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_set_js__WEBPACK_IMPORTED_MODULE_8__);\n/* harmony import */ var core_js_modules_es_string_iterator_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! core-js/modules/es.string.iterator.js */ \"./node_modules/core-js/modules/es.string.iterator.js\");\n/* harmony import */ var core_js_modules_es_string_iterator_js__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_string_iterator_js__WEBPACK_IMPORTED_MODULE_9__);\n/* harmony import */ var core_js_modules_web_dom_collections_for_each_js__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! core-js/modules/web.dom-collections.for-each.js */ \"./node_modules/core-js/modules/web.dom-collections.for-each.js\");\n/* harmony import */ var core_js_modules_web_dom_collections_for_each_js__WEBPACK_IMPORTED_MODULE_10___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_web_dom_collections_for_each_js__WEBPACK_IMPORTED_MODULE_10__);\n/* harmony import */ var core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! core-js/modules/web.dom-collections.iterator.js */ \"./node_modules/core-js/modules/web.dom-collections.iterator.js\");\n/* harmony import */ var core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_11___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_11__);\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/slicedToArray */ \"./node_modules/@babel/runtime/helpers/esm/slicedToArray.js\");\n/* harmony import */ var _vue_runtime_core__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! @vue/runtime-core */ \"./node_modules/@vue/runtime-core/dist/runtime-core.esm-bundler.js\");\n/* harmony import */ var _api_API__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! @/api/API */ \"./src/api/API.ts\");\n/* harmony import */ var _components_ChoroplethMap_vue__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! @/components/ChoroplethMap.vue */ \"./src/components/ChoroplethMap.vue\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! d3-geo */ \"./node_modules/d3-geo/src/index.js\");\n/* harmony import */ var d3_array__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! d3-array */ \"./node_modules/d3-array/src/index.js\");\n/* harmony import */ var vue_router__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! vue-router */ \"./node_modules/vue-router/dist/vue-router.esm-bundler.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n/* harmony default export */ __webpack_exports__[\"default\"] = (Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_13__[\"defineComponent\"])({\n  name: \"CompareGeos\",\n  props: {\n    projectId: {\n      type: String,\n      required: true\n    }\n  },\n  components: {\n    ChoroplethMap: _components_ChoroplethMap_vue__WEBPACK_IMPORTED_MODULE_15__[\"default\"]\n  },\n  setup: function setup(props, ctx) {\n    var selectedDimension = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_13__[\"ref\"])(\"currently_infected\");\n    var sortByMeta = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_13__[\"ref\"])(\"\");\n    var mapData = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_13__[\"ref\"])([]);\n    var cm_width = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_13__[\"ref\"])(200);\n    var cm_height = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_13__[\"ref\"])(200);\n    var topx = 20;\n    var availableDimensions = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_13__[\"ref\"])([]);\n    var availableMetas = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_13__[\"ref\"])([]);\n    var runMetas = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_13__[\"ref\"])({});\n    var regions = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_13__[\"ref\"])([]);\n    var visibleGeoObject = {};\n    var shapes = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_13__[\"ref\"])(null);\n    var projection = Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_13__[\"ref\"])(null);\n    var globalValues = {};\n    Object(_api_API__WEBPACK_IMPORTED_MODULE_14__[\"numericFields\"])(props.projectId).then(function (dims) {\n      return availableDimensions.value = dims;\n    });\n\n    var calculateProjecion = function calculateProjecion(geoObj) {\n      var geoProjection = Object(d3_geo__WEBPACK_IMPORTED_MODULE_16__[\"geoMercator\"])();\n      geoProjection.fitSize([cm_width.value, cm_height.value], geoObj);\n      return geoProjection;\n    };\n\n    var updateAll = function updateAll() {\n      mapData.value = [];\n      var metaEntries = Object.entries(runMetas.value);\n      if (metaEntries.length > 0) availableMetas.value = Object.keys(metaEntries[0][1]);\n      metaEntries.sort(function (a, b) {\n        return Object(d3_array__WEBPACK_IMPORTED_MODULE_17__[\"descending\"])(a[1][sortByMeta.value], b[1][sortByMeta.value]);\n      }).slice(0, topx).forEach(function (_ref) {\n        var _ref2 = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_12__[\"default\"])(_ref, 2),\n            runID = _ref2[0],\n            runM = _ref2[1];\n\n        var runMeta = Object.assign({}, runM, {\n          \"ID\": runID\n        }); // runMeta[\"ID\"] = runID\n\n        Promise.all(regions.value.map(function (region) {\n          return Object(_api_API__WEBPACK_IMPORTED_MODULE_14__[\"getRegionTrace\"])(props.projectId, runID, region);\n        })).then(function (regionTraces) {\n          var sparklines = {};\n          var values = {};\n          regions.value.forEach(function (regionID, i) {\n            sparklines[regionID] = regionTraces[i].map(function (t) {\n              return +t[selectedDimension.value];\n            });\n            values[regionID] = Object(d3_array__WEBPACK_IMPORTED_MODULE_17__[\"max\"])(sparklines[regionID]);\n          });\n          var mapDataEntry = {\n            runMeta: runMeta,\n            values: values,\n            sparklines: sparklines\n          };\n          mapData.value.push(mapDataEntry); //@ts-ignore\n\n          mapData.value.sort(function (a, b) {\n            return Object(d3_array__WEBPACK_IMPORTED_MODULE_17__[\"descending\"])(a.runMeta[sortByMeta.value], b.runMeta[sortByMeta.value]);\n          });\n        });\n      });\n    };\n\n    Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_13__[\"watch\"])(function () {\n      return [selectedDimension.value, sortByMeta.value];\n    }, function () {\n      updateAll();\n    });\n    var router = Object(vue_router__WEBPACK_IMPORTED_MODULE_18__[\"useRouter\"])();\n\n    var linkToDetail = function linkToDetail(e) {\n      // const path = {\n      //   name: \"geoRun\", params: {\n      //     projectId: props.projectId,\n      //     runId: e.ID,\n      //     dim: selectedDimension.value\n      //   }\n      // }\n      var path = \"/\".concat(props.projectId, \"/runDetails/\").concat(e.ID);\n      router.push({\n        path: path\n      }); // router.push(path);\n    };\n\n    Object(_vue_runtime_core__WEBPACK_IMPORTED_MODULE_13__[\"onMounted\"])(function () {\n      Promise.all([Object(_api_API__WEBPACK_IMPORTED_MODULE_14__[\"allRegions\"])(props.projectId), Object(_api_API__WEBPACK_IMPORTED_MODULE_14__[\"getGeoData\"])(props.projectId), Object(_api_API__WEBPACK_IMPORTED_MODULE_14__[\"projectRunParameters\"])(props.projectId)]).then(function (_ref3) {\n        var _ref4 = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_12__[\"default\"])(_ref3, 3),\n            r = _ref4[0],\n            geoData = _ref4[1],\n            rM = _ref4[2];\n\n        // projection:\n        var regionsSet = new Set(r);\n        visibleGeoObject = {\n          type: \"FeatureCollection\",\n          features: geoData.features.filter(function (f) {\n            return regionsSet.has(f.properties.SSID) || r.length === 0;\n          })\n        };\n        projection.value = calculateProjecion(visibleGeoObject);\n        shapes.value = geoData;\n        runMetas.value = rM;\n        regions.value = r;\n        updateAll();\n      });\n    });\n    return {\n      mapData: mapData,\n      shapes: shapes,\n      projection: projection,\n      cm_width: cm_width,\n      cm_height: cm_height,\n      sortByMeta: sortByMeta,\n      selectedDimension: selectedDimension,\n      availableDimensions: availableDimensions,\n      availableMetas: availableMetas,\n      topx: topx,\n      linkToDetail: linkToDetail\n    };\n  }\n}));\n\n//# sourceURL=webpack:///./src/views/CompareGeos.vue?./node_modules/cache-loader/dist/cjs.js??ref--13-0!./node_modules/babel-loader/lib!./node_modules/ts-loader??ref--13-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/ts-loader/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/Intro.vue?vue&type=script&lang=ts":
/*!***************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/cache-loader/dist/cjs.js??ref--13-0!./node_modules/babel-loader/lib!./node_modules/ts-loader??ref--13-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/views/Intro.vue?vue&type=script&lang=ts ***!
  \***************************************************************************************************************************************************************************************************************************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var vue__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vue */ \"./node_modules/vue/dist/vue.runtime.esm-bundler.js\");\n/* harmony import */ var _components_HelloWorld_vue__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @/components/HelloWorld.vue */ \"./src/components/HelloWorld.vue\");\n\n // @ is an alias to /src\n\n/* harmony default export */ __webpack_exports__[\"default\"] = (Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"defineComponent\"])({\n  name: \"Intro\",\n  components: {\n    HelloWorld: _components_HelloWorld_vue__WEBPACK_IMPORTED_MODULE_1__[\"default\"]\n  }\n}));\n\n//# sourceURL=webpack:///./src/views/Intro.vue?./node_modules/cache-loader/dist/cjs.js??ref--13-0!./node_modules/babel-loader/lib!./node_modules/ts-loader??ref--13-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/vue-loader-v16/dist/templateLoader.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/App.vue?vue&type=template&id=7ba5bd90":
/*!**************************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/cache-loader/dist/cjs.js??ref--12-0!./node_modules/babel-loader/lib!./node_modules/vue-loader-v16/dist/templateLoader.js??ref--6!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/App.vue?vue&type=template&id=7ba5bd90 ***!
  \**************************************************************************************************************************************************************************************************************************************************************************************************/
/*! exports provided: render */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"render\", function() { return render; });\n/* harmony import */ var vue__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vue */ \"./node_modules/vue/dist/vue.runtime.esm-bundler.js\");\n\nvar _hoisted_1 = {\n  id: \"nav\"\n};\nvar _hoisted_2 = {\n  id: \"home\"\n};\n\nvar _hoisted_3 = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"i\", {\n  class: \"fas fa-home fa-lg\"\n}, null, -1\n/* HOISTED */\n);\n\nvar _hoisted_4 = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"i\", {\n  class: \"fas fa-greater-than\",\n  style: {\n    \"margin-left\": \"1rem\"\n  }\n}, null, -1\n/* HOISTED */\n);\n\nvar _hoisted_5 = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createTextVNode\"])(\"Explore Runs\");\n\nvar _hoisted_6 = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createTextVNode\"])(\" | \");\n\nvar _hoisted_7 = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createTextVNode\"])(\"Compare Runs\");\n\nvar _hoisted_8 = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createTextVNode\"])(\" | \");\n\nvar _hoisted_9 = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createTextVNode\"])(\"Geography Overview\");\n\nfunction render(_ctx, _cache, $props, $setup, $data, $options) {\n  var _component_router_link = Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"resolveComponent\"])(\"router-link\");\n\n  var _component_router_view = Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"resolveComponent\"])(\"router-view\");\n\n  return Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(vue__WEBPACK_IMPORTED_MODULE_0__[\"Fragment\"], null, [Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"div\", _hoisted_1, [Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"div\", _hoisted_2, [Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(_component_router_link, {\n    to: \"/\"\n  }, {\n    default: Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"withCtx\"])(function () {\n      return [_hoisted_3];\n    }),\n    _: 1\n    /* STABLE */\n\n  }), _hoisted_4, Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"withDirectives\"])(Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"select\", {\n    id: \"project-selection\",\n    \"onUpdate:modelValue\": _cache[1] || (_cache[1] = function ($event) {\n      return _ctx.selectedProject = $event;\n    }),\n    style: {\n      \"margin-left\": \"1rem\"\n    }\n  }, [(Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(true), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(vue__WEBPACK_IMPORTED_MODULE_0__[\"Fragment\"], null, Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"renderList\"])(_ctx.projectNames, function (project) {\n    return Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(\"option\", {\n      value: project\n    }, Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"toDisplayString\"])(project), 9\n    /* TEXT, PROPS */\n    , [\"value\"]);\n  }), 256\n  /* UNKEYED_FRAGMENT */\n  ))], 512\n  /* NEED_PATCH */\n  ), [[vue__WEBPACK_IMPORTED_MODULE_0__[\"vModelSelect\"], _ctx.selectedProject]])]), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(_component_router_link, {\n    to: \"/\".concat(_ctx.selectedProject, \"/exploreRuns\")\n  }, {\n    default: Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"withCtx\"])(function () {\n      return [_hoisted_5];\n    }),\n    _: 1\n    /* STABLE */\n\n  }, 8\n  /* PROPS */\n  , [\"to\"]), _hoisted_6, Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(_component_router_link, {\n    to: \"/\".concat(_ctx.selectedProject, \"/runDetails/1\")\n  }, {\n    default: Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"withCtx\"])(function () {\n      return [_hoisted_7];\n    }),\n    _: 1\n    /* STABLE */\n\n  }, 8\n  /* PROPS */\n  , [\"to\"]), _hoisted_8, Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(_component_router_link, {\n    to: \"/\".concat(_ctx.selectedProject, \"/compareGeos\")\n  }, {\n    default: Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"withCtx\"])(function () {\n      return [_hoisted_9];\n    }),\n    _: 1\n    /* STABLE */\n\n  }, 8\n  /* PROPS */\n  , [\"to\"])]), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(_component_router_view)], 64\n  /* STABLE_FRAGMENT */\n  );\n}\n\n//# sourceURL=webpack:///./src/App.vue?./node_modules/cache-loader/dist/cjs.js??ref--12-0!./node_modules/babel-loader/lib!./node_modules/vue-loader-v16/dist/templateLoader.js??ref--6!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/vue-loader-v16/dist/templateLoader.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/components/ChoroplethMap.vue?vue&type=template&id=1c946f34&scoped=true":
/*!***********************************************************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/cache-loader/dist/cjs.js??ref--12-0!./node_modules/babel-loader/lib!./node_modules/vue-loader-v16/dist/templateLoader.js??ref--6!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/components/ChoroplethMap.vue?vue&type=template&id=1c946f34&scoped=true ***!
  \***********************************************************************************************************************************************************************************************************************************************************************************************************************************/
/*! exports provided: render */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"render\", function() { return render; });\n/* harmony import */ var vue__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vue */ \"./node_modules/vue/dist/vue.runtime.esm-bundler.js\");\n\n\nvar _withId = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"withScopeId\"])(\"data-v-1c946f34\");\n\nObject(vue__WEBPACK_IMPORTED_MODULE_0__[\"pushScopeId\"])(\"data-v-1c946f34\");\n\nvar _hoisted_1 = {\n  class: \"legendItem\"\n};\nvar _hoisted_2 = {\n  class: \"inlineBox\"\n};\n\nObject(vue__WEBPACK_IMPORTED_MODULE_0__[\"popScopeId\"])();\n\nvar render = /*#__PURE__*/_withId(function (_ctx, _cache, $props, $setup, $data, $options) {\n  return Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(vue__WEBPACK_IMPORTED_MODULE_0__[\"Fragment\"], null, [(Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(\"svg\", {\n    width: _ctx.width,\n    height: _ctx.height\n  }, [(Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(true), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(vue__WEBPACK_IMPORTED_MODULE_0__[\"Fragment\"], null, Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"renderList\"])(_ctx.renderShapes, function (shapePath) {\n    return Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(\"path\", {\n      class: \"site\",\n      id: shapePath.f.properties.SSID,\n      d: shapePath.path,\n      style: \"fill: \".concat(shapePath.color),\n      onMouseenter: function onMouseenter($event) {\n        return _ctx.selectedID = \"\".concat(shapePath.f.properties.SSID);\n      },\n      onMouseleave: _cache[1] || (_cache[1] = function ($event) {\n        return _ctx.selectedID = null;\n      })\n    }, null, 44\n    /* STYLE, PROPS, HYDRATE_EVENTS */\n    , [\"id\", \"d\", \"onMouseenter\"]);\n  }), 256\n  /* UNKEYED_FRAGMENT */\n  )), (Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(true), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(vue__WEBPACK_IMPORTED_MODULE_0__[\"Fragment\"], null, Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"renderList\"])(_ctx.sparklineData, function (sl) {\n    return Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(\"path\", {\n      d: sl.line,\n      class: \"sparkline\",\n      transform: \"translate(\".concat(sl.lineOffset[0] + ',' + sl.lineOffset[1], \")\")\n    }, null, 8\n    /* PROPS */\n    , [\"d\", \"transform\"]);\n  }), 256\n  /* UNKEYED_FRAGMENT */\n  )), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createCommentVNode\"])(\"      :transform=\\\"`translate(${(sl.centroid[0]-25)+','+(sl.centroid[1]-10)})`\\\"\"), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createCommentVNode\"])(\"    <text x=\\\"2\\\" y=\\\"50\\\">overlay</text>\"), (Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(true), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(vue__WEBPACK_IMPORTED_MODULE_0__[\"Fragment\"], null, Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"renderList\"])(_ctx.sparklineData, function (sl) {\n    return Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(\"path\", {\n      d: sl.line,\n      transform: \"translate(5,5)\",\n      style: {\n        \"opacity\": \"0.3\"\n      },\n      class: \"sparkline\"\n    }, null, 8\n    /* PROPS */\n    , [\"d\", \"transform\"]);\n  }), 256\n  /* UNKEYED_FRAGMENT */\n  )), (Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(true), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(vue__WEBPACK_IMPORTED_MODULE_0__[\"Fragment\"], null, Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"renderList\"])(_ctx.sparklineDots, function (dot) {\n    return Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(\"circle\", {\n      cx: dot.pos[0] + 5,\n      cy: dot.pos[1] + 5,\n      r: \"2\",\n      class: \"sparklineDot\"\n    }, null, 8\n    /* PROPS */\n    , [\"cx\", \"cy\"]);\n  }), 256\n  /* UNKEYED_FRAGMENT */\n  )), (Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(true), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(vue__WEBPACK_IMPORTED_MODULE_0__[\"Fragment\"], null, Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"renderList\"])(_ctx.sparklineDots, function (dot) {\n    return Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(\"circle\", {\n      cx: dot.pos[0],\n      cy: dot.pos[1],\n      class: \"sparklineDot\",\n      r: \"2\",\n      transform: \"translate(\".concat(dot.lineOffset[0] + ',' + dot.lineOffset[1], \")\")\n    }, null, 8\n    /* PROPS */\n    , [\"cx\", \"cy\", \"transform\"]);\n  }), 256\n  /* UNKEYED_FRAGMENT */\n  )), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createCommentVNode\"])(\"      :transform=\\\"`translate(${(dot.centroid[0]-25)+','+(dot.centroid[1]-10)})`\\\"\"), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createCommentVNode\"])(\"    </path>\"), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createCommentVNode\"])(\"    <circle\"), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createCommentVNode\"])(\"      v-for=\\\"shapePath in shapePaths\\\"\"), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createCommentVNode\"])(\"      class=\\\"noReact\\\"\"), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createCommentVNode\"])(\"      :cx=\\\"shapePath.centroid[0]\\\"\"), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createCommentVNode\"])(\"      :cy=\\\"shapePath.centroid[1]\\\"\"), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createCommentVNode\"])(\"      :r=3\"), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createCommentVNode\"])(\"    ></circle>\")], 8\n  /* PROPS */\n  , [\"width\", \"height\"])), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createCommentVNode\"])(\"  <div>{{sparklineDotIndex}}: {{sparklineDots}} </div>\"), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"div\", null, [(Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(true), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(vue__WEBPACK_IMPORTED_MODULE_0__[\"Fragment\"], null, Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"renderList\"])(_ctx.legendInfo, function (li) {\n    return Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(\"div\", _hoisted_1, [Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"div\", {\n      class: \"inlineBox colorBox\",\n      style: {\n        'background-color': li.color\n      }\n    }, null, 4\n    /* STYLE */\n    ), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"div\", _hoisted_2, Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"toDisplayString\"])(li.value), 1\n    /* TEXT */\n    )]);\n  }), 256\n  /* UNKEYED_FRAGMENT */\n  ))]), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createCommentVNode\"])(\"  <pre>{{ sparklineData }}</pre>\")], 64\n  /* STABLE_FRAGMENT */\n  );\n});\n\n//# sourceURL=webpack:///./src/components/ChoroplethMap.vue?./node_modules/cache-loader/dist/cjs.js??ref--12-0!./node_modules/babel-loader/lib!./node_modules/vue-loader-v16/dist/templateLoader.js??ref--6!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/vue-loader-v16/dist/templateLoader.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/components/HelloWorld.vue?vue&type=template&id=469af010&scoped=true":
/*!********************************************************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/cache-loader/dist/cjs.js??ref--12-0!./node_modules/babel-loader/lib!./node_modules/vue-loader-v16/dist/templateLoader.js??ref--6!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/components/HelloWorld.vue?vue&type=template&id=469af010&scoped=true ***!
  \********************************************************************************************************************************************************************************************************************************************************************************************************************************/
/*! exports provided: render */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"render\", function() { return render; });\n/* harmony import */ var vue__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vue */ \"./node_modules/vue/dist/vue.runtime.esm-bundler.js\");\n\n\nvar _withId = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"withScopeId\"])(\"data-v-469af010\");\n\nObject(vue__WEBPACK_IMPORTED_MODULE_0__[\"pushScopeId\"])(\"data-v-469af010\");\n\nvar _hoisted_1 = {\n  class: \"hello\"\n};\n\nObject(vue__WEBPACK_IMPORTED_MODULE_0__[\"popScopeId\"])();\n\nvar render = /*#__PURE__*/_withId(function (_ctx, _cache, $props, $setup, $data, $options) {\n  return Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(\"div\", _hoisted_1, [Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"h1\", null, Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"toDisplayString\"])(_ctx.msg), 1\n  /* TEXT */\n  )]);\n});\n\n//# sourceURL=webpack:///./src/components/HelloWorld.vue?./node_modules/cache-loader/dist/cjs.js??ref--12-0!./node_modules/babel-loader/lib!./node_modules/vue-loader-v16/dist/templateLoader.js??ref--6!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/vue-loader-v16/dist/templateLoader.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/CompareGeos.vue?vue&type=template&id=64742406&scoped=true":
/*!****************************************************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/cache-loader/dist/cjs.js??ref--12-0!./node_modules/babel-loader/lib!./node_modules/vue-loader-v16/dist/templateLoader.js??ref--6!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/views/CompareGeos.vue?vue&type=template&id=64742406&scoped=true ***!
  \****************************************************************************************************************************************************************************************************************************************************************************************************************************/
/*! exports provided: render */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"render\", function() { return render; });\n/* harmony import */ var core_js_modules_es_object_keys_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! core-js/modules/es.object.keys.js */ \"./node_modules/core-js/modules/es.object.keys.js\");\n/* harmony import */ var core_js_modules_es_object_keys_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_object_keys_js__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! core-js/modules/es.object.to-string.js */ \"./node_modules/core-js/modules/es.object.to-string.js\");\n/* harmony import */ var core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! core-js/modules/web.dom-collections.iterator.js */ \"./node_modules/core-js/modules/web.dom-collections.iterator.js\");\n/* harmony import */ var core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_2__);\n/* harmony import */ var vue__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! vue */ \"./node_modules/vue/dist/vue.runtime.esm-bundler.js\");\n\n\n\n\n\nvar _withId = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"withScopeId\"])(\"data-v-64742406\");\n\nObject(vue__WEBPACK_IMPORTED_MODULE_3__[\"pushScopeId\"])(\"data-v-64742406\");\n\nvar _hoisted_1 = {\n  class: \"main container\"\n};\n\nvar _hoisted_2 = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(\"h2\", {\n  class: \"title\"\n}, \"Geography Overview\", -1\n/* HOISTED */\n);\n\nvar _hoisted_3 = {\n  class: \"row intro\"\n};\nvar _hoisted_4 = {\n  class: \"col-12 muted\"\n};\n\nvar _hoisted_5 = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(\"p\", null, \" This page shows the simulated impact of Covid-19 across geographical regions. \", -1\n/* HOISTED */\n);\n\nvar _hoisted_6 = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(\"span\", {\n  style: {\n    \"color\": \"var(--darkred)\"\n  }\n}, \"Red curves\", -1\n/* HOISTED */\n);\n\nvar _hoisted_7 = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createTextVNode\"])(\" show the trend of the selected variable of interest for each region, whereas the \");\n\nvar _hoisted_8 = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(\"span\", {\n  style: {\n    \"color\": \"black\"\n  }\n}, \"grey shading\", -1\n/* HOISTED */\n);\n\nvar _hoisted_9 = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(\"p\", null, [/*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createTextVNode\"])(\" Use the dropdown menus to select the variable that is plotted on each card, and select the run parameter with which to sort these cards (optional). Clicking on a card will take you to the \"), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(\"span\", {\n  class: \"tab\"\n}, \"Compare Runs\"), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createTextVNode\"])(\" page to view the run in more detail. \")], -1\n/* HOISTED */\n);\n\nvar _hoisted_10 = {\n  class: \"optionBox\"\n};\n\nvar _hoisted_11 = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(\"label\", {\n  for: \"dimSel\"\n}, \"Variable of Interest: \", -1\n/* HOISTED */\n);\n\nvar _hoisted_12 = {\n  class: \"optionBox\"\n};\n\nvar _hoisted_13 = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(\"label\", {\n  for: \"sortSel\"\n}, \"Sort by: \", -1\n/* HOISTED */\n);\n\nvar _hoisted_14 = {\n  class: \"small\"\n};\nvar _hoisted_15 = {\n  class: \"map\"\n};\n\nObject(vue__WEBPACK_IMPORTED_MODULE_3__[\"popScopeId\"])();\n\nvar render = /*#__PURE__*/_withId(function (_ctx, _cache, $props, $setup, $data, $options) {\n  var _component_ChoroplethMap = Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"resolveComponent\"])(\"ChoroplethMap\");\n\n  return Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createBlock\"])(\"div\", _hoisted_1, [_hoisted_2, Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(\"div\", _hoisted_3, [Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(\"div\", _hoisted_4, [_hoisted_5, Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(\"p\", null, [_hoisted_6, _hoisted_7, _hoisted_8, Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createTextVNode\"])(\" reveals which regions were impacted the most over the course of each simulation. Each region is colored to reflect the maximum value observed for the variable of interest (\" + Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"toDisplayString\"])(_ctx.selectedDimension) + \"), with values corresponding to the lightest and darkest shades shown as dots on the bottom left corner of each card. \", 1\n  /* TEXT */\n  )]), _hoisted_9])]), Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createCommentVNode\"])(\"  <div>{{ availableDimensions }}</div>\"), Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(\"div\", _hoisted_10, [_hoisted_11, Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"withDirectives\"])(Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(\"select\", {\n    \"onUpdate:modelValue\": _cache[1] || (_cache[1] = function ($event) {\n      return _ctx.selectedDimension = $event;\n    }),\n    id: \"dimSel\"\n  }, [(Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"openBlock\"])(true), Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createBlock\"])(vue__WEBPACK_IMPORTED_MODULE_3__[\"Fragment\"], null, Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"renderList\"])(_ctx.availableDimensions, function (dim) {\n    return Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createBlock\"])(\"option\", {\n      value: dim\n    }, Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"toDisplayString\"])(dim), 9\n    /* TEXT, PROPS */\n    , [\"value\"]);\n  }), 256\n  /* UNKEYED_FRAGMENT */\n  ))], 512\n  /* NEED_PATCH */\n  ), [[vue__WEBPACK_IMPORTED_MODULE_3__[\"vModelSelect\"], _ctx.selectedDimension]])]), Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(\"div\", _hoisted_12, [_hoisted_13, Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"withDirectives\"])(Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(\"select\", {\n    \"onUpdate:modelValue\": _cache[2] || (_cache[2] = function ($event) {\n      return _ctx.sortByMeta = $event;\n    }),\n    id: \"sortSel\"\n  }, [(Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"openBlock\"])(true), Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createBlock\"])(vue__WEBPACK_IMPORTED_MODULE_3__[\"Fragment\"], null, Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"renderList\"])(_ctx.availableMetas, function (dim) {\n    return Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createBlock\"])(\"option\", {\n      value: dim\n    }, Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"toDisplayString\"])(dim), 9\n    /* TEXT, PROPS */\n    , [\"value\"]);\n  }), 256\n  /* UNKEYED_FRAGMENT */\n  ))], 512\n  /* NEED_PATCH */\n  ), [[vue__WEBPACK_IMPORTED_MODULE_3__[\"vModelSelect\"], _ctx.sortByMeta]])]), (Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"openBlock\"])(true), Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createBlock\"])(vue__WEBPACK_IMPORTED_MODULE_3__[\"Fragment\"], null, Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"renderList\"])(_ctx.mapData, function (md) {\n    return Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createBlock\"])(\"div\", {\n      class: \"geoInfo\",\n      onClick: function onClick($event) {\n        return _ctx.linkToDetail(md.runMeta);\n      }\n    }, [Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(\"div\", null, \"Run \" + Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"toDisplayString\"])(md.runMeta.ID), 1\n    /* TEXT */\n    ), (Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"openBlock\"])(true), Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createBlock\"])(vue__WEBPACK_IMPORTED_MODULE_3__[\"Fragment\"], null, Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"renderList\"])(Object.keys(md.runMeta), function (key) {\n      return Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createBlock\"])(\"div\", _hoisted_14, [Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(\"span\", {\n        class: key === _ctx.sortByMeta ? 'sortedBy' : ''\n      }, Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"toDisplayString\"])(key), 3\n      /* TEXT, CLASS */\n      ), Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createTextVNode\"])(\": \" + Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"toDisplayString\"])(md.runMeta[key]), 1\n      /* TEXT */\n      )]);\n    }), 256\n    /* UNKEYED_FRAGMENT */\n    )), Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(\"div\", _hoisted_15, [Object(vue__WEBPACK_IMPORTED_MODULE_3__[\"createVNode\"])(_component_ChoroplethMap, {\n      shapes: _ctx.shapes,\n      values: md.values,\n      sparklines: md.sparklines,\n      projection: _ctx.projection,\n      width: _ctx.cm_width,\n      height: _ctx.cm_height\n    }, null, 8\n    /* PROPS */\n    , [\"shapes\", \"values\", \"sparklines\", \"projection\", \"width\", \"height\"])])], 8\n    /* PROPS */\n    , [\"onClick\"]);\n  }), 256\n  /* UNKEYED_FRAGMENT */\n  ))]);\n});\n\n//# sourceURL=webpack:///./src/views/CompareGeos.vue?./node_modules/cache-loader/dist/cjs.js??ref--12-0!./node_modules/babel-loader/lib!./node_modules/vue-loader-v16/dist/templateLoader.js??ref--6!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/vue-loader-v16/dist/templateLoader.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/Intro.vue?vue&type=template&id=f12fd2bc&scoped=true":
/*!**********************************************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/cache-loader/dist/cjs.js??ref--12-0!./node_modules/babel-loader/lib!./node_modules/vue-loader-v16/dist/templateLoader.js??ref--6!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/views/Intro.vue?vue&type=template&id=f12fd2bc&scoped=true ***!
  \**********************************************************************************************************************************************************************************************************************************************************************************************************************/
/*! exports provided: render */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"render\", function() { return render; });\n/* harmony import */ var vue__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! vue */ \"./node_modules/vue/dist/vue.runtime.esm-bundler.js\");\n/* harmony import */ var _assets_GP_logo_RGB_svg__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../assets/GP_logo_RGB.svg */ \"./src/assets/GP_logo_RGB.svg\");\n/* harmony import */ var _assets_GP_logo_RGB_svg__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_assets_GP_logo_RGB_svg__WEBPACK_IMPORTED_MODULE_1__);\n\n\n\nvar _withId = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"withScopeId\"])(\"data-v-f12fd2bc\");\n\nObject(vue__WEBPACK_IMPORTED_MODULE_0__[\"pushScopeId\"])(\"data-v-f12fd2bc\");\n\nvar _hoisted_1 = {\n  class: \"container main\"\n};\n\nvar _hoisted_2 = /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"div\", {\n  class: \"row\"\n}, [/*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"div\", {\n  class: \"col-2\"\n}, [/*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"br\"), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"img\", {\n  alt: \"Global Pulse Logo\",\n  src: _assets_GP_logo_RGB_svg__WEBPACK_IMPORTED_MODULE_1___default.a,\n  class: \"right\"\n}), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"img\", {\n  src: \"\",\n  alt: \"\"\n})]), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"div\", {\n  class: \"col-10\"\n}, [/*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createCommentVNode\"])(\"    <img alt=\\\"Vue logo\\\" src=\\\"../assets/logo.png\\\">\"), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"h2\", {\n  class: \"with-subtitle\"\n}, \"Welcome to Camp Dashboard\"), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"h4\", {\n  class: \"muted subtitle\"\n}, \" An operational response simulation tool for epidemics within settlements \"), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"p\", null, [/*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createTextVNode\"])(\" This dashboard presents the modelling results of an agent-based \"), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"a\", {\n  href: \"https://www.unglobalpulse.org/2020/10/modelling-the-spread-of-covid-19-and-the-impact-of-public-health-interventions-in-coxs-bazar-and-other-refugee-camps/\"\n}, \" epidemiological simulation for Cox’s Bazar, Bangladesh\"), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createTextVNode\"])(\" using \"), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"a\", {\n  href: \"https://github.com/bhoov/JUNE-vis\"\n}, \"JUNE-vis\"), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createTextVNode\"])(\". \")]), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"p\", null, [/*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createTextVNode\"])(\" Here, you can compare simulations of how the COVID-19 epidemic could evolve under several scenarios comparing the effectiveness of mask wearing. You can create visualizations for new \"), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"a\", {\n  href: \"https://github.com/IDAS-Durham/JUNE\"\n}, \"JUNE\"), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createTextVNode\"])(\" simulations by following the \"), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"a\", {\n  href: \"https://bhoov.github.io/JUNE-vis/Create%20Project.html\"\n}, \"instructions\"), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createTextVNode\"])(\". \")]), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"br\"), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"p\", {\n  class: \"muted-3\"\n}, [/*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createTextVNode\"])(\" A short example of how to use this dashboard can be used can be found in Section 7 of the accompanying paper: \"), /*#__PURE__*/Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createVNode\"])(\"a\", {\n  href: \"https://www.medrxiv.org/content/10.1101/2021.01.27.21250611v1\"\n}, \"Operational response simulation tool for epidemics within refugee and IDP settlements\")])])], -1\n/* HOISTED */\n);\n\nObject(vue__WEBPACK_IMPORTED_MODULE_0__[\"popScopeId\"])();\n\nvar render = /*#__PURE__*/_withId(function (_ctx, _cache, $props, $setup, $data, $options) {\n  return Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"openBlock\"])(), Object(vue__WEBPACK_IMPORTED_MODULE_0__[\"createBlock\"])(\"div\", _hoisted_1, [_hoisted_2]);\n});\n\n//# sourceURL=webpack:///./src/views/Intro.vue?./node_modules/cache-loader/dist/cjs.js??ref--12-0!./node_modules/babel-loader/lib!./node_modules/vue-loader-v16/dist/templateLoader.js??ref--6!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/Intro.vue?vue&type=style&index=0&id=f12fd2bc&scoped=true&lang=css":
/*!******************************************************************************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/css-loader/dist/cjs.js??ref--6-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--6-oneOf-1-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/views/Intro.vue?vue&type=style&index=0&id=f12fd2bc&scoped=true&lang=css ***!
  \******************************************************************************************************************************************************************************************************************************************************************************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("// Imports\nvar ___CSS_LOADER_API_IMPORT___ = __webpack_require__(/*! ../../node_modules/css-loader/dist/runtime/api.js */ \"./node_modules/css-loader/dist/runtime/api.js\");\nexports = ___CSS_LOADER_API_IMPORT___(false);\n// Module\nexports.push([module.i, \"\\n.main[data-v-f12fd2bc] {\\n  max-width: 1080px;\\n}\\n.home[data-v-f12fd2bc] {\\n  margin: auto;\\n  line-height: 1.6;\\n}\\na[data-v-f12fd2bc]:visited {\\n  color: var(--darkblue);\\n}\\n.with-subtitle[data-v-f12fd2bc] {\\n  margin-bottom: 0rem;\\n  padding-bottom: 0rem;\\n}\\n.subtitle[data-v-f12fd2bc] {\\n  margin-top: 0.8rem;\\n  padding-top: 0rem;\\n  /* font-style: oblique; */\\n}\\n.param[data-v-f12fd2bc] {\\n  font-weight: 600;\\n  /* border-bottom: 1px dashed black; */\\n}\\n.param-option[data-v-f12fd2bc] {\\n  /* font-weight: 600; */\\n  /* font-style: oblique; */\\n  border-bottom: 1px dashed black;\\n}\\n.plot-info[data-v-f12fd2bc] {\\n  font-weight: 600;\\n  /*border-bottom: 1px dotted black;*/\\n}\\n\", \"\"]);\n// Exports\nmodule.exports = exports;\n\n\n//# sourceURL=webpack:///./src/views/Intro.vue?./node_modules/css-loader/dist/cjs.js??ref--6-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--6-oneOf-1-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/sass-loader/dist/cjs.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/App.vue?vue&type=style&index=0&id=7ba5bd90&lang=scss":
/*!********************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--8-oneOf-1-2!./node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/App.vue?vue&type=style&index=0&id=7ba5bd90&lang=scss ***!
  \********************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("// Imports\nvar ___CSS_LOADER_API_IMPORT___ = __webpack_require__(/*! ../node_modules/css-loader/dist/runtime/api.js */ \"./node_modules/css-loader/dist/runtime/api.js\");\nexports = ___CSS_LOADER_API_IMPORT___(false);\nexports.push([module.i, \"@import url(https://fonts.googleapis.com/css?family=Lato:400,300,300italic,400italic,700,700italic);\"]);\n// Module\nexports.push([module.i, \"#app {\\n  -webkit-font-smoothing: antialiased;\\n  -moz-osx-font-smoothing: grayscale;\\n  color: #2c3e50;\\n}\\n:root {\\n  --gpblue: #00aeef;\\n  --darkred: #9b4531;\\n  --yellow: #ffb100;\\n  --orange: #cf8236;\\n  --brightblue: #007be0;\\n  --olive: #665e1e;\\n  --teal: #007be0;\\n  --darkblue: #00447c;\\n  --lightred: #cf5c42;\\n  --grey: #5d6263;\\n  --lightgrey: #96999b;\\n  --lightblue: #e1f4fd;\\n}\\nbody {\\n  color: #5d6263;\\n  background: #ffffff;\\n  font-family: \\\"Literata\\\", sans-serif;\\n  size: 18px;\\n  line-height: 1.5;\\n  font-weight: 500;\\n}\\nh1,\\nh2,\\nh3,\\nh4,\\nh5,\\nh6 {\\n  color: #1e1e1e;\\n  background: #ffffff;\\n  font-family: \\\"Rubik\\\", sans-serif;\\n  font-weight: bold;\\n  line-height: 1;\\n}\\nh1 {\\n  font-size: 48px;\\n}\\nh2 {\\n  font-size: 34px;\\n}\\nh3 {\\n  font-size: 26px;\\n}\\nh4 {\\n  font-size: 22px;\\n}\\nh5 {\\n  font-size: 18px;\\n}\\nh6 {\\n  font-size: 15px;\\n}\\na {\\n  color: #333;\\n}\\n.muted {\\n  color: rgba(50, 50, 50, 0.75);\\n}\\n.muted-3 {\\n  opacity: 0.7;\\n}\\n.muted-5 {\\n  opacity: 0.5;\\n}\\n.muted-8 {\\n  opacity: 0.2;\\n}\\n.tab {\\n  font-weight: 900;\\n  font-size: 17px;\\n  font-family: \\\"Rubik\\\", sans-serif;\\n}\\n.tab-option::before {\\n  content: open-quote;\\n}\\n.tab-option::after {\\n  content: close-quote;\\n}\\n#home {\\n  position: absolute;\\n  margin: auto;\\n  margin: 0 1rem;\\n}\\n#nav {\\n  padding: 15px;\\n  margin-bottom: 1rem;\\n  width: 100%;\\n  background: var(--lightblue);\\n  text-align: center;\\n}\\n#nav a {\\n  font-size: 17px;\\n  font-family: \\\"Rubik\\\", sans-serif;\\n  text-decoration: none;\\n}\\n#nav a.router-link-exact-active {\\n  font-weight: 900;\\n}\\n#nav a.router-link-active {\\n  font-weight: 900;\\n}\\n#nav a:hover {\\n  text-decoration: underline;\\n}\\n\\n/**\\n*** SIMPLE GRID\\n*** (C) ZACH COLE 2016\\n**/\\n/* UNIVERSAL */\\n/* ROOT FONT STYLES */\\n/* POSITIONING */\\n.left {\\n  text-align: left;\\n}\\n.right {\\n  text-align: right;\\n}\\n.center {\\n  text-align: center;\\n  margin-left: auto;\\n  margin-right: auto;\\n}\\n.justify {\\n  text-align: justify;\\n}\\n\\n/* ==== GRID SYSTEM ==== */\\n.container {\\n  width: 100%;\\n  margin-left: auto;\\n  margin-right: auto;\\n}\\n.row {\\n  position: relative;\\n  width: 100%;\\n}\\n.row [class^=col] {\\n  float: left;\\n  margin: 0.5rem 2%;\\n  min-height: 0.125rem;\\n}\\n.col-1,\\n.col-2,\\n.col-3,\\n.col-4,\\n.col-5,\\n.col-6,\\n.col-7,\\n.col-8,\\n.col-9,\\n.col-10,\\n.col-11,\\n.col-12 {\\n  width: 96%;\\n}\\n.col-1-sm {\\n  width: 4.33%;\\n}\\n.col-2-sm {\\n  width: 12.66%;\\n}\\n.col-3-sm {\\n  width: 21%;\\n}\\n.col-4-sm {\\n  width: 29.33%;\\n}\\n.col-5-sm {\\n  width: 37.66%;\\n}\\n.col-6-sm {\\n  width: 46%;\\n}\\n.col-7-sm {\\n  width: 54.33%;\\n}\\n.col-8-sm {\\n  width: 62.66%;\\n}\\n.col-9-sm {\\n  width: 71%;\\n}\\n.col-10-sm {\\n  width: 79.33%;\\n}\\n.col-11-sm {\\n  width: 87.66%;\\n}\\n.col-12-sm {\\n  width: 96%;\\n}\\n.row::after {\\n  content: \\\"\\\";\\n  display: table;\\n  clear: both;\\n}\\n.hidden-sm {\\n  display: none;\\n}\\n@media only screen and (min-width: 45em) {\\n  /* 720px */\\n.col-1 {\\n    width: 4.33%;\\n}\\n.col-2 {\\n    width: 12.66%;\\n}\\n.col-3 {\\n    width: 21%;\\n}\\n.col-4 {\\n    width: 29.33%;\\n}\\n.col-5 {\\n    width: 37.66%;\\n}\\n.col-6 {\\n    width: 46%;\\n}\\n.col-7 {\\n    width: 54.33%;\\n}\\n.col-8 {\\n    width: 62.66%;\\n}\\n.col-9 {\\n    width: 71%;\\n}\\n.col-10 {\\n    width: 79.33%;\\n}\\n.col-11 {\\n    width: 87.66%;\\n}\\n.col-12 {\\n    width: 96%;\\n}\\n.hidden-sm {\\n    display: block;\\n}\\n.working {\\n    cursor: progress !important;\\n}\\n}\", \"\"]);\n// Exports\nmodule.exports = exports;\n\n\n//# sourceURL=webpack:///./src/App.vue?./node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--8-oneOf-1-2!./node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/sass-loader/dist/cjs.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/components/ChoroplethMap.vue?vue&type=style&index=0&id=1c946f34&scoped=true&lang=scss":
/*!*****************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--8-oneOf-1-2!./node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/components/ChoroplethMap.vue?vue&type=style&index=0&id=1c946f34&scoped=true&lang=scss ***!
  \*****************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("// Imports\nvar ___CSS_LOADER_API_IMPORT___ = __webpack_require__(/*! ../../node_modules/css-loader/dist/runtime/api.js */ \"./node_modules/css-loader/dist/runtime/api.js\");\nexports = ___CSS_LOADER_API_IMPORT___(false);\n// Module\nexports.push([module.i, \".sparklineDot[data-v-1c946f34] {\\n  fill: #cc2949;\\n  pointer-events: none;\\n  stroke-width: 1;\\n  stroke: #dedede;\\n}\\n.inlineBox[data-v-1c946f34] {\\n  display: inline-block;\\n  vertical-align: middle;\\n}\\n.colorBox[data-v-1c946f34] {\\n  width: 16px;\\n  height: 16px;\\n  border-radius: 8px;\\n  margin-right: 2px;\\n}\\n.legendItem[data-v-1c946f34] {\\n  margin-right: 5px;\\n  white-space: nowrap;\\n  display: inline-block;\\n}\\n.noReact[data-v-1c946f34] {\\n  pointer-events: none;\\n}\\n.sparkline[data-v-1c946f34] {\\n  fill: none;\\n  stroke-width: 2;\\n  stroke: #cc2949;\\n}\\n.site[data-v-1c946f34] {\\n  fill: #ffffff;\\n  stroke: #2c3e50;\\n  stroke-width: 0.5;\\n  transition-duration: 50ms;\\n}\\n.site[data-v-1c946f34]:hover {\\n  fill: #2c3e50;\\n  transition-duration: 200ms;\\n  stroke: #3e77b1;\\n  stroke-width: 2;\\n}\", \"\"]);\n// Exports\nmodule.exports = exports;\n\n\n//# sourceURL=webpack:///./src/components/ChoroplethMap.vue?./node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--8-oneOf-1-2!./node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/sass-loader/dist/cjs.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/components/HelloWorld.vue?vue&type=style&index=0&id=469af010&scoped=true&lang=scss":
/*!**************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--8-oneOf-1-2!./node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/components/HelloWorld.vue?vue&type=style&index=0&id=469af010&scoped=true&lang=scss ***!
  \**************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("// Imports\nvar ___CSS_LOADER_API_IMPORT___ = __webpack_require__(/*! ../../node_modules/css-loader/dist/runtime/api.js */ \"./node_modules/css-loader/dist/runtime/api.js\");\nexports = ___CSS_LOADER_API_IMPORT___(false);\n// Module\nexports.push([module.i, \"h3[data-v-469af010] {\\n  margin: 40px 0 0;\\n}\\nul[data-v-469af010] {\\n  list-style-type: none;\\n  padding: 0;\\n}\\nli[data-v-469af010] {\\n  display: inline-block;\\n  margin: 0 10px;\\n}\\na[data-v-469af010] {\\n  color: #42b983;\\n}\", \"\"]);\n// Exports\nmodule.exports = exports;\n\n\n//# sourceURL=webpack:///./src/components/HelloWorld.vue?./node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--8-oneOf-1-2!./node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/sass-loader/dist/cjs.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/CompareGeos.vue?vue&type=style&index=0&id=64742406&scoped=true&lang=scss":
/*!**********************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--8-oneOf-1-2!./node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/views/CompareGeos.vue?vue&type=style&index=0&id=64742406&scoped=true&lang=scss ***!
  \**********************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("// Imports\nvar ___CSS_LOADER_API_IMPORT___ = __webpack_require__(/*! ../../node_modules/css-loader/dist/runtime/api.js */ \"./node_modules/css-loader/dist/runtime/api.js\");\nexports = ___CSS_LOADER_API_IMPORT___(false);\n// Module\nexports.push([module.i, \".main[data-v-64742406] {\\n  margin: 1rem 2rem;\\n}\\n.map[data-v-64742406] {\\n  margin: 5px 0;\\n  pointer-events: none;\\n}\\nlabel[data-v-64742406] {\\n  font-weight: bold;\\n}\\n.optionBox[data-v-64742406] {\\n  margin: 10px 0;\\n  width: 100%;\\n  white-space: nowrap;\\n}\\nselect[data-v-64742406] {\\n  padding: 5px;\\n  border: none;\\n  font: inherit;\\n}\\n.geoInfo[data-v-64742406] {\\n  display: inline-block;\\n  margin: 3px;\\n  padding: 5px;\\n  border: 1px black solid;\\n  border-radius: 5px;\\n}\\n.geoInfo[data-v-64742406]:hover {\\n  background-color: #eee;\\n}\\n.sortedBy[data-v-64742406] {\\n  font-weight: 800;\\n}\\n.small[data-v-64742406] {\\n  font-family: monospace;\\n  font-size: 8pt;\\n}\", \"\"]);\n// Exports\nmodule.exports = exports;\n\n\n//# sourceURL=webpack:///./src/views/CompareGeos.vue?./node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--8-oneOf-1-2!./node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/vue-style-loader/index.js?!./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/Intro.vue?vue&type=style&index=0&id=f12fd2bc&scoped=true&lang=css":
/*!********************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/vue-style-loader??ref--6-oneOf-1-0!./node_modules/css-loader/dist/cjs.js??ref--6-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--6-oneOf-1-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/views/Intro.vue?vue&type=style&index=0&id=f12fd2bc&scoped=true&lang=css ***!
  \********************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("// style-loader: Adds some css to the DOM by adding a <style> tag\n\n// load the styles\nvar content = __webpack_require__(/*! !../../node_modules/css-loader/dist/cjs.js??ref--6-oneOf-1-1!../../node_modules/vue-loader-v16/dist/stylePostLoader.js!../../node_modules/postcss-loader/src??ref--6-oneOf-1-2!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./Intro.vue?vue&type=style&index=0&id=f12fd2bc&scoped=true&lang=css */ \"./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/Intro.vue?vue&type=style&index=0&id=f12fd2bc&scoped=true&lang=css\");\nif(typeof content === 'string') content = [[module.i, content, '']];\nif(content.locals) module.exports = content.locals;\n// add the styles to the DOM\nvar add = __webpack_require__(/*! ../../node_modules/vue-style-loader/lib/addStylesClient.js */ \"./node_modules/vue-style-loader/lib/addStylesClient.js\").default\nvar update = add(\"e08b6b36\", content, false, {\"sourceMap\":false,\"shadowMode\":false});\n// Hot Module Replacement\nif(false) {}\n\n//# sourceURL=webpack:///./src/views/Intro.vue?./node_modules/vue-style-loader??ref--6-oneOf-1-0!./node_modules/css-loader/dist/cjs.js??ref--6-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--6-oneOf-1-2!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/vue-style-loader/index.js?!./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/sass-loader/dist/cjs.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/App.vue?vue&type=style&index=0&id=7ba5bd90&lang=scss":
/*!**********************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/vue-style-loader??ref--8-oneOf-1-0!./node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--8-oneOf-1-2!./node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/App.vue?vue&type=style&index=0&id=7ba5bd90&lang=scss ***!
  \**********************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("// style-loader: Adds some css to the DOM by adding a <style> tag\n\n// load the styles\nvar content = __webpack_require__(/*! !../node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!../node_modules/vue-loader-v16/dist/stylePostLoader.js!../node_modules/postcss-loader/src??ref--8-oneOf-1-2!../node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!../node_modules/cache-loader/dist/cjs.js??ref--0-0!../node_modules/vue-loader-v16/dist??ref--0-1!./App.vue?vue&type=style&index=0&id=7ba5bd90&lang=scss */ \"./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/sass-loader/dist/cjs.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/App.vue?vue&type=style&index=0&id=7ba5bd90&lang=scss\");\nif(typeof content === 'string') content = [[module.i, content, '']];\nif(content.locals) module.exports = content.locals;\n// add the styles to the DOM\nvar add = __webpack_require__(/*! ../node_modules/vue-style-loader/lib/addStylesClient.js */ \"./node_modules/vue-style-loader/lib/addStylesClient.js\").default\nvar update = add(\"2cce70f6\", content, false, {\"sourceMap\":false,\"shadowMode\":false});\n// Hot Module Replacement\nif(false) {}\n\n//# sourceURL=webpack:///./src/App.vue?./node_modules/vue-style-loader??ref--8-oneOf-1-0!./node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--8-oneOf-1-2!./node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/vue-style-loader/index.js?!./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/sass-loader/dist/cjs.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/components/ChoroplethMap.vue?vue&type=style&index=0&id=1c946f34&scoped=true&lang=scss":
/*!*******************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/vue-style-loader??ref--8-oneOf-1-0!./node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--8-oneOf-1-2!./node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/components/ChoroplethMap.vue?vue&type=style&index=0&id=1c946f34&scoped=true&lang=scss ***!
  \*******************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("// style-loader: Adds some css to the DOM by adding a <style> tag\n\n// load the styles\nvar content = __webpack_require__(/*! !../../node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!../../node_modules/vue-loader-v16/dist/stylePostLoader.js!../../node_modules/postcss-loader/src??ref--8-oneOf-1-2!../../node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./ChoroplethMap.vue?vue&type=style&index=0&id=1c946f34&scoped=true&lang=scss */ \"./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/sass-loader/dist/cjs.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/components/ChoroplethMap.vue?vue&type=style&index=0&id=1c946f34&scoped=true&lang=scss\");\nif(typeof content === 'string') content = [[module.i, content, '']];\nif(content.locals) module.exports = content.locals;\n// add the styles to the DOM\nvar add = __webpack_require__(/*! ../../node_modules/vue-style-loader/lib/addStylesClient.js */ \"./node_modules/vue-style-loader/lib/addStylesClient.js\").default\nvar update = add(\"d051f4d8\", content, false, {\"sourceMap\":false,\"shadowMode\":false});\n// Hot Module Replacement\nif(false) {}\n\n//# sourceURL=webpack:///./src/components/ChoroplethMap.vue?./node_modules/vue-style-loader??ref--8-oneOf-1-0!./node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--8-oneOf-1-2!./node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/vue-style-loader/index.js?!./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/sass-loader/dist/cjs.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/components/HelloWorld.vue?vue&type=style&index=0&id=469af010&scoped=true&lang=scss":
/*!****************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/vue-style-loader??ref--8-oneOf-1-0!./node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--8-oneOf-1-2!./node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/components/HelloWorld.vue?vue&type=style&index=0&id=469af010&scoped=true&lang=scss ***!
  \****************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("// style-loader: Adds some css to the DOM by adding a <style> tag\n\n// load the styles\nvar content = __webpack_require__(/*! !../../node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!../../node_modules/vue-loader-v16/dist/stylePostLoader.js!../../node_modules/postcss-loader/src??ref--8-oneOf-1-2!../../node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./HelloWorld.vue?vue&type=style&index=0&id=469af010&scoped=true&lang=scss */ \"./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/sass-loader/dist/cjs.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/components/HelloWorld.vue?vue&type=style&index=0&id=469af010&scoped=true&lang=scss\");\nif(typeof content === 'string') content = [[module.i, content, '']];\nif(content.locals) module.exports = content.locals;\n// add the styles to the DOM\nvar add = __webpack_require__(/*! ../../node_modules/vue-style-loader/lib/addStylesClient.js */ \"./node_modules/vue-style-loader/lib/addStylesClient.js\").default\nvar update = add(\"3b894ee6\", content, false, {\"sourceMap\":false,\"shadowMode\":false});\n// Hot Module Replacement\nif(false) {}\n\n//# sourceURL=webpack:///./src/components/HelloWorld.vue?./node_modules/vue-style-loader??ref--8-oneOf-1-0!./node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--8-oneOf-1-2!./node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./node_modules/vue-style-loader/index.js?!./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/sass-loader/dist/cjs.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/CompareGeos.vue?vue&type=style&index=0&id=64742406&scoped=true&lang=scss":
/*!************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************!*\
  !*** ./node_modules/vue-style-loader??ref--8-oneOf-1-0!./node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--8-oneOf-1-2!./node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1!./src/views/CompareGeos.vue?vue&type=style&index=0&id=64742406&scoped=true&lang=scss ***!
  \************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("// style-loader: Adds some css to the DOM by adding a <style> tag\n\n// load the styles\nvar content = __webpack_require__(/*! !../../node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!../../node_modules/vue-loader-v16/dist/stylePostLoader.js!../../node_modules/postcss-loader/src??ref--8-oneOf-1-2!../../node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./CompareGeos.vue?vue&type=style&index=0&id=64742406&scoped=true&lang=scss */ \"./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/sass-loader/dist/cjs.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/CompareGeos.vue?vue&type=style&index=0&id=64742406&scoped=true&lang=scss\");\nif(typeof content === 'string') content = [[module.i, content, '']];\nif(content.locals) module.exports = content.locals;\n// add the styles to the DOM\nvar add = __webpack_require__(/*! ../../node_modules/vue-style-loader/lib/addStylesClient.js */ \"./node_modules/vue-style-loader/lib/addStylesClient.js\").default\nvar update = add(\"5aacaab3\", content, false, {\"sourceMap\":false,\"shadowMode\":false});\n// Hot Module Replacement\nif(false) {}\n\n//# sourceURL=webpack:///./src/views/CompareGeos.vue?./node_modules/vue-style-loader??ref--8-oneOf-1-0!./node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src??ref--8-oneOf-1-2!./node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!./node_modules/cache-loader/dist/cjs.js??ref--0-0!./node_modules/vue-loader-v16/dist??ref--0-1");

/***/ }),

/***/ "./src/App.vue":
/*!*********************!*\
  !*** ./src/App.vue ***!
  \*********************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _App_vue_vue_type_template_id_7ba5bd90__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./App.vue?vue&type=template&id=7ba5bd90 */ \"./src/App.vue?vue&type=template&id=7ba5bd90\");\n/* harmony import */ var _App_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./App.vue?vue&type=script&lang=ts */ \"./src/App.vue?vue&type=script&lang=ts\");\n/* empty/unused harmony star reexport *//* harmony import */ var _App_vue_vue_type_style_index_0_id_7ba5bd90_lang_scss__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./App.vue?vue&type=style&index=0&id=7ba5bd90&lang=scss */ \"./src/App.vue?vue&type=style&index=0&id=7ba5bd90&lang=scss\");\n\n\n\n\n\n_App_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"].render = _App_vue_vue_type_template_id_7ba5bd90__WEBPACK_IMPORTED_MODULE_0__[\"render\"]\n/* hot reload */\nif (false) {}\n\n_App_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"].__file = \"src/App.vue\"\n\n/* harmony default export */ __webpack_exports__[\"default\"] = (_App_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"]);\n\n//# sourceURL=webpack:///./src/App.vue?");

/***/ }),

/***/ "./src/App.vue?vue&type=script&lang=ts":
/*!*********************************************!*\
  !*** ./src/App.vue?vue&type=script&lang=ts ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _node_modules_cache_loader_dist_cjs_js_ref_13_0_node_modules_babel_loader_lib_index_js_node_modules_ts_loader_index_js_ref_13_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_App_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! -!../node_modules/cache-loader/dist/cjs.js??ref--13-0!../node_modules/babel-loader/lib!../node_modules/ts-loader??ref--13-2!../node_modules/cache-loader/dist/cjs.js??ref--0-0!../node_modules/vue-loader-v16/dist??ref--0-1!./App.vue?vue&type=script&lang=ts */ \"./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/ts-loader/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/App.vue?vue&type=script&lang=ts\");\n/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, \"default\", function() { return _node_modules_cache_loader_dist_cjs_js_ref_13_0_node_modules_babel_loader_lib_index_js_node_modules_ts_loader_index_js_ref_13_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_App_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_0__[\"default\"]; });\n\n/* empty/unused harmony star reexport */ \n\n//# sourceURL=webpack:///./src/App.vue?");

/***/ }),

/***/ "./src/App.vue?vue&type=style&index=0&id=7ba5bd90&lang=scss":
/*!******************************************************************!*\
  !*** ./src/App.vue?vue&type=style&index=0&id=7ba5bd90&lang=scss ***!
  \******************************************************************/
/*! no static exports found */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_App_vue_vue_type_style_index_0_id_7ba5bd90_lang_scss__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! -!../node_modules/vue-style-loader??ref--8-oneOf-1-0!../node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!../node_modules/vue-loader-v16/dist/stylePostLoader.js!../node_modules/postcss-loader/src??ref--8-oneOf-1-2!../node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!../node_modules/cache-loader/dist/cjs.js??ref--0-0!../node_modules/vue-loader-v16/dist??ref--0-1!./App.vue?vue&type=style&index=0&id=7ba5bd90&lang=scss */ \"./node_modules/vue-style-loader/index.js?!./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/sass-loader/dist/cjs.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/App.vue?vue&type=style&index=0&id=7ba5bd90&lang=scss\");\n/* harmony import */ var _node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_App_vue_vue_type_style_index_0_id_7ba5bd90_lang_scss__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_App_vue_vue_type_style_index_0_id_7ba5bd90_lang_scss__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony reexport (unknown) */ for(var __WEBPACK_IMPORT_KEY__ in _node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_App_vue_vue_type_style_index_0_id_7ba5bd90_lang_scss__WEBPACK_IMPORTED_MODULE_0__) if([\"default\"].indexOf(__WEBPACK_IMPORT_KEY__) < 0) (function(key) { __webpack_require__.d(__webpack_exports__, key, function() { return _node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_App_vue_vue_type_style_index_0_id_7ba5bd90_lang_scss__WEBPACK_IMPORTED_MODULE_0__[key]; }) }(__WEBPACK_IMPORT_KEY__));\n\n\n//# sourceURL=webpack:///./src/App.vue?");

/***/ }),

/***/ "./src/App.vue?vue&type=template&id=7ba5bd90":
/*!***************************************************!*\
  !*** ./src/App.vue?vue&type=template&id=7ba5bd90 ***!
  \***************************************************/
/*! exports provided: render */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _node_modules_cache_loader_dist_cjs_js_ref_12_0_node_modules_babel_loader_lib_index_js_node_modules_vue_loader_v16_dist_templateLoader_js_ref_6_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_App_vue_vue_type_template_id_7ba5bd90__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! -!../node_modules/cache-loader/dist/cjs.js??ref--12-0!../node_modules/babel-loader/lib!../node_modules/vue-loader-v16/dist/templateLoader.js??ref--6!../node_modules/cache-loader/dist/cjs.js??ref--0-0!../node_modules/vue-loader-v16/dist??ref--0-1!./App.vue?vue&type=template&id=7ba5bd90 */ \"./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/vue-loader-v16/dist/templateLoader.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/App.vue?vue&type=template&id=7ba5bd90\");\n/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, \"render\", function() { return _node_modules_cache_loader_dist_cjs_js_ref_12_0_node_modules_babel_loader_lib_index_js_node_modules_vue_loader_v16_dist_templateLoader_js_ref_6_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_App_vue_vue_type_template_id_7ba5bd90__WEBPACK_IMPORTED_MODULE_0__[\"render\"]; });\n\n\n\n//# sourceURL=webpack:///./src/App.vue?");

/***/ }),

/***/ "./src/api/API.ts":
/*!************************!*\
  !*** ./src/api/API.ts ***!
  \************************/
/*! exports provided: allProjectNames, getProject, projectDescription, projectRunParameters, getRun, getRuns, getTrace, getTraces, getRegionTrace, getParamSelection, getTraceWithField, getRunParameters, getFieldExtent, allRegions, allFields, numericFields, allDatetimes, allTimestamps, getGeoData, getGeoProjection, filterByParamSelection, getLegend, baseNumericFields */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"allProjectNames\", function() { return allProjectNames; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getProject\", function() { return getProject; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"projectDescription\", function() { return projectDescription; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"projectRunParameters\", function() { return projectRunParameters; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getRun\", function() { return getRun; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getRuns\", function() { return getRuns; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getTrace\", function() { return getTrace; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getTraces\", function() { return getTraces; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getRegionTrace\", function() { return getRegionTrace; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getParamSelection\", function() { return getParamSelection; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getTraceWithField\", function() { return getTraceWithField; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getRunParameters\", function() { return getRunParameters; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getFieldExtent\", function() { return getFieldExtent; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"allRegions\", function() { return allRegions; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"allFields\", function() { return allFields; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"numericFields\", function() { return numericFields; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"allDatetimes\", function() { return allDatetimes; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"allTimestamps\", function() { return allTimestamps; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getGeoData\", function() { return getGeoData; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getGeoProjection\", function() { return getGeoProjection; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"filterByParamSelection\", function() { return filterByParamSelection; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getLegend\", function() { return getLegend; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"baseNumericFields\", function() { return baseNumericFields; });\n/* harmony import */ var core_js_modules_es_symbol_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! core-js/modules/es.symbol.js */ \"./node_modules/core-js/modules/es.symbol.js\");\n/* harmony import */ var core_js_modules_es_symbol_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_symbol_js__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var core_js_modules_es_symbol_description_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! core-js/modules/es.symbol.description.js */ \"./node_modules/core-js/modules/es.symbol.description.js\");\n/* harmony import */ var core_js_modules_es_symbol_description_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_symbol_description_js__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var core_js_modules_es_array_concat_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! core-js/modules/es.array.concat.js */ \"./node_modules/core-js/modules/es.array.concat.js\");\n/* harmony import */ var core_js_modules_es_array_concat_js__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_concat_js__WEBPACK_IMPORTED_MODULE_2__);\n/* harmony import */ var core_js_modules_es_array_filter_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! core-js/modules/es.array.filter.js */ \"./node_modules/core-js/modules/es.array.filter.js\");\n/* harmony import */ var core_js_modules_es_array_filter_js__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_filter_js__WEBPACK_IMPORTED_MODULE_3__);\n/* harmony import */ var core_js_modules_es_array_map_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! core-js/modules/es.array.map.js */ \"./node_modules/core-js/modules/es.array.map.js\");\n/* harmony import */ var core_js_modules_es_array_map_js__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_map_js__WEBPACK_IMPORTED_MODULE_4__);\n/* harmony import */ var core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! core-js/modules/es.object.to-string.js */ \"./node_modules/core-js/modules/es.object.to-string.js\");\n/* harmony import */ var core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_5__);\n/* harmony import */ var core_js_modules_es_regexp_exec_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! core-js/modules/es.regexp.exec.js */ \"./node_modules/core-js/modules/es.regexp.exec.js\");\n/* harmony import */ var core_js_modules_es_regexp_exec_js__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_regexp_exec_js__WEBPACK_IMPORTED_MODULE_6__);\n/* harmony import */ var core_js_modules_es_string_split_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! core-js/modules/es.string.split.js */ \"./node_modules/core-js/modules/es.string.split.js\");\n/* harmony import */ var core_js_modules_es_string_split_js__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_string_split_js__WEBPACK_IMPORTED_MODULE_7__);\n/* harmony import */ var core_js_modules_es_string_trim_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! core-js/modules/es.string.trim.js */ \"./node_modules/core-js/modules/es.string.trim.js\");\n/* harmony import */ var core_js_modules_es_string_trim_js__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_string_trim_js__WEBPACK_IMPORTED_MODULE_8__);\n/* harmony import */ var core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! core-js/modules/web.dom-collections.iterator.js */ \"./node_modules/core-js/modules/web.dom-collections.iterator.js\");\n/* harmony import */ var core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_9__);\n/* harmony import */ var regenerator_runtime_runtime_js__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! regenerator-runtime/runtime.js */ \"./node_modules/regenerator-runtime/runtime.js\");\n/* harmony import */ var regenerator_runtime_runtime_js__WEBPACK_IMPORTED_MODULE_10___default = /*#__PURE__*/__webpack_require__.n(regenerator_runtime_runtime_js__WEBPACK_IMPORTED_MODULE_10__);\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/asyncToGenerator */ \"./node_modules/@babel/runtime/helpers/esm/asyncToGenerator.js\");\n/* harmony import */ var d3_fetch__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! d3-fetch */ \"./node_modules/d3-fetch/src/index.js\");\n/* harmony import */ var _utils_cacher__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! @/utils/cacher */ \"./src/utils/cacher.ts\");\n/* harmony import */ var _logic_JuneProject__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! @/logic/JuneProject */ \"./src/logic/JuneProject.ts\");\n/* harmony import */ var _logic_display__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! @/logic/display */ \"./src/logic/display.ts\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n/**\n * API file for requesting the information needed by the frontend.\n *\n * Only include methods that return data as needed for the interface.\n * All views and components should only need to call this file to fetch\n * the data they need\n */\n\n\n\n\nvar allProjectNames = Object(_utils_cacher__WEBPACK_IMPORTED_MODULE_13__[\"memoize\"])( /*#__PURE__*/Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {\n  var value;\n  return regeneratorRuntime.wrap(function _callee$(_context) {\n    while (1) {\n      switch (_context.prev = _context.next) {\n        case 0:\n          _context.next = 2;\n          return Object(d3_fetch__WEBPACK_IMPORTED_MODULE_12__[\"text\"])(\"demo/availableProjects.txt\");\n\n        case 2:\n          value = _context.sent;\n          return _context.abrupt(\"return\", value.trim().split(\"\\n\"));\n\n        case 4:\n        case \"end\":\n          return _context.stop();\n      }\n    }\n  }, _callee);\n})));\nvar getProject = Object(_utils_cacher__WEBPACK_IMPORTED_MODULE_13__[\"memoize\"])(function (p_id) {\n  return _logic_JuneProject__WEBPACK_IMPORTED_MODULE_14__[\"JuneProject\"].build(p_id);\n});\nfunction projectDescription(_x) {\n  return _projectDescription.apply(this, arguments);\n}\n\nfunction _projectDescription() {\n  _projectDescription = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(p_id) {\n    var project;\n    return regeneratorRuntime.wrap(function _callee2$(_context2) {\n      while (1) {\n        switch (_context2.prev = _context2.next) {\n          case 0:\n            _context2.next = 2;\n            return getProject(p_id);\n\n          case 2:\n            project = _context2.sent;\n            return _context2.abrupt(\"return\", project.description);\n\n          case 4:\n          case \"end\":\n            return _context2.stop();\n        }\n      }\n    }, _callee2);\n  }));\n  return _projectDescription.apply(this, arguments);\n}\n\nfunction projectRunParameters(_x2) {\n  return _projectRunParameters.apply(this, arguments);\n}\n\nfunction _projectRunParameters() {\n  _projectRunParameters = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee3(p_id) {\n    var project;\n    return regeneratorRuntime.wrap(function _callee3$(_context3) {\n      while (1) {\n        switch (_context3.prev = _context3.next) {\n          case 0:\n            _context3.next = 2;\n            return getProject(p_id);\n\n          case 2:\n            project = _context3.sent;\n            return _context3.abrupt(\"return\", project.run_parameters);\n\n          case 4:\n          case \"end\":\n            return _context3.stop();\n        }\n      }\n    }, _callee3);\n  }));\n  return _projectRunParameters.apply(this, arguments);\n}\n\nfunction getRun(_x3, _x4) {\n  return _getRun.apply(this, arguments);\n}\n\nfunction _getRun() {\n  _getRun = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee4(p_id, run_id) {\n    var project;\n    return regeneratorRuntime.wrap(function _callee4$(_context4) {\n      while (1) {\n        switch (_context4.prev = _context4.next) {\n          case 0:\n            _context4.next = 2;\n            return getProject(p_id);\n\n          case 2:\n            project = _context4.sent;\n            return _context4.abrupt(\"return\", project.getRun(run_id));\n\n          case 4:\n          case \"end\":\n            return _context4.stop();\n        }\n      }\n    }, _callee4);\n  }));\n  return _getRun.apply(this, arguments);\n}\n\nfunction getRuns(_x5, _x6) {\n  return _getRuns.apply(this, arguments);\n}\n/**\n * Return the trace for a single region\n */\n\nfunction _getRuns() {\n  _getRuns = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee5(p_id, run_ids) {\n    var project;\n    return regeneratorRuntime.wrap(function _callee5$(_context5) {\n      while (1) {\n        switch (_context5.prev = _context5.next) {\n          case 0:\n            _context5.next = 2;\n            return getProject(p_id);\n\n          case 2:\n            project = _context5.sent;\n            return _context5.abrupt(\"return\", project.getRuns(run_ids));\n\n          case 4:\n          case \"end\":\n            return _context5.stop();\n        }\n      }\n    }, _callee5);\n  }));\n  return _getRuns.apply(this, arguments);\n}\n\nfunction getTrace(_x7, _x8, _x9) {\n  return _getTrace.apply(this, arguments);\n}\n/**\n * Return the traces for a single region\n */\n\nfunction _getTrace() {\n  _getTrace = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee6(p_id, run_id, region) {\n    var run;\n    return regeneratorRuntime.wrap(function _callee6$(_context6) {\n      while (1) {\n        switch (_context6.prev = _context6.next) {\n          case 0:\n            _context6.next = 2;\n            return getRun(p_id, run_id);\n\n          case 2:\n            run = _context6.sent;\n            return _context6.abrupt(\"return\", run.values.filter(function (v) {\n              return v.region == region;\n            }));\n\n          case 4:\n          case \"end\":\n            return _context6.stop();\n        }\n      }\n    }, _callee6);\n  }));\n  return _getTrace.apply(this, arguments);\n}\n\nfunction getTraces(_x10, _x11, _x12) {\n  return _getTraces.apply(this, arguments);\n}\n/**\n * Get the trace representing all the information from a region\n */\n\nfunction _getTraces() {\n  _getTraces = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee7(p_id, run_ids, region) {\n    var runs;\n    return regeneratorRuntime.wrap(function _callee7$(_context7) {\n      while (1) {\n        switch (_context7.prev = _context7.next) {\n          case 0:\n            _context7.next = 2;\n            return getRuns(p_id, run_ids);\n\n          case 2:\n            runs = _context7.sent;\n            return _context7.abrupt(\"return\", runs.map(function (r) {\n              return r.values.filter(function (v) {\n                return v.region == region;\n              });\n            }));\n\n          case 4:\n          case \"end\":\n            return _context7.stop();\n        }\n      }\n    }, _callee7);\n  }));\n  return _getTraces.apply(this, arguments);\n}\n\nfunction getRegionTrace(_x13, _x14, _x15) {\n  return _getRegionTrace.apply(this, arguments);\n}\n\nfunction _getRegionTrace() {\n  _getRegionTrace = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee8(p_id, run_id, region) {\n    var run;\n    return regeneratorRuntime.wrap(function _callee8$(_context8) {\n      while (1) {\n        switch (_context8.prev = _context8.next) {\n          case 0:\n            _context8.next = 2;\n            return getRun(p_id, run_id);\n\n          case 2:\n            run = _context8.sent;\n            return _context8.abrupt(\"return\", run.aggregateByRegion(region));\n\n          case 4:\n          case \"end\":\n            return _context8.stop();\n        }\n      }\n    }, _callee8);\n  }));\n  return _getRegionTrace.apply(this, arguments);\n}\n\nfunction getParamSelection(_x16) {\n  return _getParamSelection.apply(this, arguments);\n}\n/**\n * Return the trace for a single region, given a particular field\n */\n\nfunction _getParamSelection() {\n  _getParamSelection = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee9(p_id) {\n    var project;\n    return regeneratorRuntime.wrap(function _callee9$(_context9) {\n      while (1) {\n        switch (_context9.prev = _context9.next) {\n          case 0:\n            _context9.next = 2;\n            return getProject(p_id);\n\n          case 2:\n            project = _context9.sent;\n            return _context9.abrupt(\"return\", project.paramList);\n\n          case 4:\n          case \"end\":\n            return _context9.stop();\n        }\n      }\n    }, _callee9);\n  }));\n  return _getParamSelection.apply(this, arguments);\n}\n\nfunction getTraceWithField(_x17, _x18, _x19, _x20) {\n  return _getTraceWithField.apply(this, arguments);\n}\n/**\n * Extract default run-parameters for project\n */\n\nfunction _getTraceWithField() {\n  _getTraceWithField = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee10(p_id, run_id, region, field) {\n    var run;\n    return regeneratorRuntime.wrap(function _callee10$(_context10) {\n      while (1) {\n        switch (_context10.prev = _context10.next) {\n          case 0:\n            _context10.next = 2;\n            return getRun(p_id, run_id);\n\n          case 2:\n            run = _context10.sent;\n            return _context10.abrupt(\"return\", run.getTraceWithField(region, field));\n\n          case 4:\n          case \"end\":\n            return _context10.stop();\n        }\n      }\n    }, _callee10);\n  }));\n  return _getTraceWithField.apply(this, arguments);\n}\n\nfunction getRunParameters(_x21, _x22) {\n  return _getRunParameters.apply(this, arguments);\n}\n/**\n * Get the extent of different min max across field names\n */\n\nfunction _getRunParameters() {\n  _getRunParameters = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee11(p_id, run_id) {\n    var run;\n    return regeneratorRuntime.wrap(function _callee11$(_context11) {\n      while (1) {\n        switch (_context11.prev = _context11.next) {\n          case 0:\n            _context11.next = 2;\n            return getRun(p_id, run_id);\n\n          case 2:\n            run = _context11.sent;\n            return _context11.abrupt(\"return\", run.run_parameters);\n\n          case 4:\n          case \"end\":\n            return _context11.stop();\n        }\n      }\n    }, _callee11);\n  }));\n  return _getRunParameters.apply(this, arguments);\n}\n\nfunction getFieldExtent(_x23, _x24) {\n  return _getFieldExtent.apply(this, arguments);\n}\n\nfunction _getFieldExtent() {\n  _getFieldExtent = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee12(p_id, fieldNames) {\n    var project;\n    return regeneratorRuntime.wrap(function _callee12$(_context12) {\n      while (1) {\n        switch (_context12.prev = _context12.next) {\n          case 0:\n            _context12.next = 2;\n            return getProject(p_id);\n\n          case 2:\n            project = _context12.sent;\n            return _context12.abrupt(\"return\", project.fieldExtent(fieldNames));\n\n          case 4:\n          case \"end\":\n            return _context12.stop();\n        }\n      }\n    }, _callee12);\n  }));\n  return _getFieldExtent.apply(this, arguments);\n}\n\nfunction allRegions(_x25) {\n  return _allRegions.apply(this, arguments);\n}\n\nfunction _allRegions() {\n  _allRegions = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee13(p_id) {\n    var project;\n    return regeneratorRuntime.wrap(function _callee13$(_context13) {\n      while (1) {\n        switch (_context13.prev = _context13.next) {\n          case 0:\n            _context13.next = 2;\n            return getProject(p_id);\n\n          case 2:\n            project = _context13.sent;\n            return _context13.abrupt(\"return\", project.all_regions);\n\n          case 4:\n          case \"end\":\n            return _context13.stop();\n        }\n      }\n    }, _callee13);\n  }));\n  return _allRegions.apply(this, arguments);\n}\n\nfunction allFields(_x26) {\n  return _allFields.apply(this, arguments);\n}\n\nfunction _allFields() {\n  _allFields = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee14(p_id) {\n    var project;\n    return regeneratorRuntime.wrap(function _callee14$(_context14) {\n      while (1) {\n        switch (_context14.prev = _context14.next) {\n          case 0:\n            _context14.next = 2;\n            return getProject(p_id);\n\n          case 2:\n            project = _context14.sent;\n            return _context14.abrupt(\"return\", project.all_fields);\n\n          case 4:\n          case \"end\":\n            return _context14.stop();\n        }\n      }\n    }, _callee14);\n  }));\n  return _allFields.apply(this, arguments);\n}\n\nfunction numericFields(_x27) {\n  return _numericFields.apply(this, arguments);\n}\n\nfunction _numericFields() {\n  _numericFields = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee15(p_id) {\n    var project;\n    return regeneratorRuntime.wrap(function _callee15$(_context15) {\n      while (1) {\n        switch (_context15.prev = _context15.next) {\n          case 0:\n            _context15.next = 2;\n            return getProject(p_id);\n\n          case 2:\n            project = _context15.sent;\n            return _context15.abrupt(\"return\", project.numeric_fields);\n\n          case 4:\n          case \"end\":\n            return _context15.stop();\n        }\n      }\n    }, _callee15);\n  }));\n  return _numericFields.apply(this, arguments);\n}\n\nfunction allDatetimes(_x28) {\n  return _allDatetimes.apply(this, arguments);\n}\n\nfunction _allDatetimes() {\n  _allDatetimes = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee16(p_id) {\n    var project;\n    return regeneratorRuntime.wrap(function _callee16$(_context16) {\n      while (1) {\n        switch (_context16.prev = _context16.next) {\n          case 0:\n            _context16.next = 2;\n            return getProject(p_id);\n\n          case 2:\n            project = _context16.sent;\n            return _context16.abrupt(\"return\", project.all_datetimes);\n\n          case 4:\n          case \"end\":\n            return _context16.stop();\n        }\n      }\n    }, _callee16);\n  }));\n  return _allDatetimes.apply(this, arguments);\n}\n\nfunction allTimestamps(_x29) {\n  return _allTimestamps.apply(this, arguments);\n}\n\nfunction _allTimestamps() {\n  _allTimestamps = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee17(p_id) {\n    var project;\n    return regeneratorRuntime.wrap(function _callee17$(_context17) {\n      while (1) {\n        switch (_context17.prev = _context17.next) {\n          case 0:\n            _context17.next = 2;\n            return getProject(p_id);\n\n          case 2:\n            project = _context17.sent;\n            return _context17.abrupt(\"return\", project.all_timestamps);\n\n          case 4:\n          case \"end\":\n            return _context17.stop();\n        }\n      }\n    }, _callee17);\n  }));\n  return _allTimestamps.apply(this, arguments);\n}\n\nfunction getGeoData(_x30) {\n  return _getGeoData.apply(this, arguments);\n}\n\nfunction _getGeoData() {\n  _getGeoData = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee18(p_id) {\n    var project;\n    return regeneratorRuntime.wrap(function _callee18$(_context18) {\n      while (1) {\n        switch (_context18.prev = _context18.next) {\n          case 0:\n            _context18.next = 2;\n            return getProject(p_id);\n\n          case 2:\n            project = _context18.sent;\n            return _context18.abrupt(\"return\", project.geoFile());\n\n          case 4:\n          case \"end\":\n            return _context18.stop();\n        }\n      }\n    }, _callee18);\n  }));\n  return _getGeoData.apply(this, arguments);\n}\n\nfunction getGeoProjection(_x31, _x32, _x33) {\n  return _getGeoProjection.apply(this, arguments);\n}\n\nfunction _getGeoProjection() {\n  _getGeoProjection = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee19(p_id, width, height) {\n    var project;\n    return regeneratorRuntime.wrap(function _callee19$(_context19) {\n      while (1) {\n        switch (_context19.prev = _context19.next) {\n          case 0:\n            _context19.next = 2;\n            return getProject(p_id);\n\n          case 2:\n            project = _context19.sent;\n            return _context19.abrupt(\"return\", project.geoProjection(width, height));\n\n          case 4:\n          case \"end\":\n            return _context19.stop();\n        }\n      }\n    }, _callee19);\n  }));\n  return _getGeoProjection.apply(this, arguments);\n}\n\nfunction filterByParamSelection(_x34, _x35) {\n  return _filterByParamSelection.apply(this, arguments);\n}\n/**\n *  Get legend values across paramName\n */\n\nfunction _filterByParamSelection() {\n  _filterByParamSelection = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee20(p_id, query) {\n    var project;\n    return regeneratorRuntime.wrap(function _callee20$(_context20) {\n      while (1) {\n        switch (_context20.prev = _context20.next) {\n          case 0:\n            _context20.next = 2;\n            return getProject(p_id);\n\n          case 2:\n            project = _context20.sent;\n            return _context20.abrupt(\"return\", project.filterBySelection(query));\n\n          case 4:\n          case \"end\":\n            return _context20.stop();\n        }\n      }\n    }, _callee20);\n  }));\n  return _filterByParamSelection.apply(this, arguments);\n}\n\nfunction getLegend(_x36, _x37, _x38) {\n  return _getLegend.apply(this, arguments);\n}\n\nfunction _getLegend() {\n  _getLegend = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee21(p_id, run_ids, paramName) {\n    var runs;\n    return regeneratorRuntime.wrap(function _callee21$(_context21) {\n      while (1) {\n        switch (_context21.prev = _context21.next) {\n          case 0:\n            _context21.next = 2;\n            return getRuns(p_id, run_ids);\n\n          case 2:\n            runs = _context21.sent;\n            return _context21.abrupt(\"return\", runs.map(function (run) {\n              var v = run.run_parameters[paramName];\n\n              if (paramName == \"\") {\n                return \"run-\".concat(run.runId);\n              }\n\n              return \"\".concat(paramName, \"=\").concat(Object(_logic_display__WEBPACK_IMPORTED_MODULE_15__[\"formatValDisplay\"])(v));\n            }));\n\n          case 4:\n          case \"end\":\n            return _context21.stop();\n        }\n      }\n    }, _callee21);\n  }));\n  return _getLegend.apply(this, arguments);\n}\n\nfunction baseNumericFields(_x39) {\n  return _baseNumericFields.apply(this, arguments);\n}\n\nfunction _baseNumericFields() {\n  _baseNumericFields = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_11__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee22(p_id) {\n    var project, out;\n    return regeneratorRuntime.wrap(function _callee22$(_context22) {\n      while (1) {\n        switch (_context22.prev = _context22.next) {\n          case 0:\n            _context22.next = 2;\n            return getProject(p_id);\n\n          case 2:\n            project = _context22.sent;\n            out = project.baseNumericFields;\n            return _context22.abrupt(\"return\", out);\n\n          case 5:\n          case \"end\":\n            return _context22.stop();\n        }\n      }\n    }, _callee22);\n  }));\n  return _baseNumericFields.apply(this, arguments);\n}\n\n//# sourceURL=webpack:///./src/api/API.ts?");

/***/ }),

/***/ "./src/assets/GP_logo_RGB.svg":
/*!************************************!*\
  !*** ./src/assets/GP_logo_RGB.svg ***!
  \************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("module.exports = __webpack_require__.p + \"img/GP_logo_RGB.ee184764.svg\";\n\n//# sourceURL=webpack:///./src/assets/GP_logo_RGB.svg?");

/***/ }),

/***/ "./src/components/ChoroplethMap.vue":
/*!******************************************!*\
  !*** ./src/components/ChoroplethMap.vue ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _ChoroplethMap_vue_vue_type_template_id_1c946f34_scoped_true__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./ChoroplethMap.vue?vue&type=template&id=1c946f34&scoped=true */ \"./src/components/ChoroplethMap.vue?vue&type=template&id=1c946f34&scoped=true\");\n/* harmony import */ var _ChoroplethMap_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./ChoroplethMap.vue?vue&type=script&lang=ts */ \"./src/components/ChoroplethMap.vue?vue&type=script&lang=ts\");\n/* empty/unused harmony star reexport *//* harmony import */ var _ChoroplethMap_vue_vue_type_style_index_0_id_1c946f34_scoped_true_lang_scss__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./ChoroplethMap.vue?vue&type=style&index=0&id=1c946f34&scoped=true&lang=scss */ \"./src/components/ChoroplethMap.vue?vue&type=style&index=0&id=1c946f34&scoped=true&lang=scss\");\n\n\n\n\n\n_ChoroplethMap_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"].render = _ChoroplethMap_vue_vue_type_template_id_1c946f34_scoped_true__WEBPACK_IMPORTED_MODULE_0__[\"render\"]\n_ChoroplethMap_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"].__scopeId = \"data-v-1c946f34\"\n/* hot reload */\nif (false) {}\n\n_ChoroplethMap_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"].__file = \"src/components/ChoroplethMap.vue\"\n\n/* harmony default export */ __webpack_exports__[\"default\"] = (_ChoroplethMap_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"]);\n\n//# sourceURL=webpack:///./src/components/ChoroplethMap.vue?");

/***/ }),

/***/ "./src/components/ChoroplethMap.vue?vue&type=script&lang=ts":
/*!******************************************************************!*\
  !*** ./src/components/ChoroplethMap.vue?vue&type=script&lang=ts ***!
  \******************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _node_modules_cache_loader_dist_cjs_js_ref_13_0_node_modules_babel_loader_lib_index_js_node_modules_ts_loader_index_js_ref_13_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_ChoroplethMap_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! -!../../node_modules/cache-loader/dist/cjs.js??ref--13-0!../../node_modules/babel-loader/lib!../../node_modules/ts-loader??ref--13-2!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./ChoroplethMap.vue?vue&type=script&lang=ts */ \"./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/ts-loader/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/components/ChoroplethMap.vue?vue&type=script&lang=ts\");\n/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, \"default\", function() { return _node_modules_cache_loader_dist_cjs_js_ref_13_0_node_modules_babel_loader_lib_index_js_node_modules_ts_loader_index_js_ref_13_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_ChoroplethMap_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_0__[\"default\"]; });\n\n/* empty/unused harmony star reexport */ \n\n//# sourceURL=webpack:///./src/components/ChoroplethMap.vue?");

/***/ }),

/***/ "./src/components/ChoroplethMap.vue?vue&type=style&index=0&id=1c946f34&scoped=true&lang=scss":
/*!***************************************************************************************************!*\
  !*** ./src/components/ChoroplethMap.vue?vue&type=style&index=0&id=1c946f34&scoped=true&lang=scss ***!
  \***************************************************************************************************/
/*! no static exports found */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_ChoroplethMap_vue_vue_type_style_index_0_id_1c946f34_scoped_true_lang_scss__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! -!../../node_modules/vue-style-loader??ref--8-oneOf-1-0!../../node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!../../node_modules/vue-loader-v16/dist/stylePostLoader.js!../../node_modules/postcss-loader/src??ref--8-oneOf-1-2!../../node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./ChoroplethMap.vue?vue&type=style&index=0&id=1c946f34&scoped=true&lang=scss */ \"./node_modules/vue-style-loader/index.js?!./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/sass-loader/dist/cjs.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/components/ChoroplethMap.vue?vue&type=style&index=0&id=1c946f34&scoped=true&lang=scss\");\n/* harmony import */ var _node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_ChoroplethMap_vue_vue_type_style_index_0_id_1c946f34_scoped_true_lang_scss__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_ChoroplethMap_vue_vue_type_style_index_0_id_1c946f34_scoped_true_lang_scss__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony reexport (unknown) */ for(var __WEBPACK_IMPORT_KEY__ in _node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_ChoroplethMap_vue_vue_type_style_index_0_id_1c946f34_scoped_true_lang_scss__WEBPACK_IMPORTED_MODULE_0__) if([\"default\"].indexOf(__WEBPACK_IMPORT_KEY__) < 0) (function(key) { __webpack_require__.d(__webpack_exports__, key, function() { return _node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_ChoroplethMap_vue_vue_type_style_index_0_id_1c946f34_scoped_true_lang_scss__WEBPACK_IMPORTED_MODULE_0__[key]; }) }(__WEBPACK_IMPORT_KEY__));\n\n\n//# sourceURL=webpack:///./src/components/ChoroplethMap.vue?");

/***/ }),

/***/ "./src/components/ChoroplethMap.vue?vue&type=template&id=1c946f34&scoped=true":
/*!************************************************************************************!*\
  !*** ./src/components/ChoroplethMap.vue?vue&type=template&id=1c946f34&scoped=true ***!
  \************************************************************************************/
/*! exports provided: render */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _node_modules_cache_loader_dist_cjs_js_ref_12_0_node_modules_babel_loader_lib_index_js_node_modules_vue_loader_v16_dist_templateLoader_js_ref_6_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_ChoroplethMap_vue_vue_type_template_id_1c946f34_scoped_true__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! -!../../node_modules/cache-loader/dist/cjs.js??ref--12-0!../../node_modules/babel-loader/lib!../../node_modules/vue-loader-v16/dist/templateLoader.js??ref--6!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./ChoroplethMap.vue?vue&type=template&id=1c946f34&scoped=true */ \"./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/vue-loader-v16/dist/templateLoader.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/components/ChoroplethMap.vue?vue&type=template&id=1c946f34&scoped=true\");\n/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, \"render\", function() { return _node_modules_cache_loader_dist_cjs_js_ref_12_0_node_modules_babel_loader_lib_index_js_node_modules_vue_loader_v16_dist_templateLoader_js_ref_6_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_ChoroplethMap_vue_vue_type_template_id_1c946f34_scoped_true__WEBPACK_IMPORTED_MODULE_0__[\"render\"]; });\n\n\n\n//# sourceURL=webpack:///./src/components/ChoroplethMap.vue?");

/***/ }),

/***/ "./src/components/HelloWorld.vue":
/*!***************************************!*\
  !*** ./src/components/HelloWorld.vue ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _HelloWorld_vue_vue_type_template_id_469af010_scoped_true__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./HelloWorld.vue?vue&type=template&id=469af010&scoped=true */ \"./src/components/HelloWorld.vue?vue&type=template&id=469af010&scoped=true\");\n/* harmony import */ var _HelloWorld_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./HelloWorld.vue?vue&type=script&lang=ts */ \"./src/components/HelloWorld.vue?vue&type=script&lang=ts\");\n/* empty/unused harmony star reexport *//* harmony import */ var _HelloWorld_vue_vue_type_style_index_0_id_469af010_scoped_true_lang_scss__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./HelloWorld.vue?vue&type=style&index=0&id=469af010&scoped=true&lang=scss */ \"./src/components/HelloWorld.vue?vue&type=style&index=0&id=469af010&scoped=true&lang=scss\");\n\n\n\n\n\n_HelloWorld_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"].render = _HelloWorld_vue_vue_type_template_id_469af010_scoped_true__WEBPACK_IMPORTED_MODULE_0__[\"render\"]\n_HelloWorld_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"].__scopeId = \"data-v-469af010\"\n/* hot reload */\nif (false) {}\n\n_HelloWorld_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"].__file = \"src/components/HelloWorld.vue\"\n\n/* harmony default export */ __webpack_exports__[\"default\"] = (_HelloWorld_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"]);\n\n//# sourceURL=webpack:///./src/components/HelloWorld.vue?");

/***/ }),

/***/ "./src/components/HelloWorld.vue?vue&type=script&lang=ts":
/*!***************************************************************!*\
  !*** ./src/components/HelloWorld.vue?vue&type=script&lang=ts ***!
  \***************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _node_modules_cache_loader_dist_cjs_js_ref_13_0_node_modules_babel_loader_lib_index_js_node_modules_ts_loader_index_js_ref_13_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_HelloWorld_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! -!../../node_modules/cache-loader/dist/cjs.js??ref--13-0!../../node_modules/babel-loader/lib!../../node_modules/ts-loader??ref--13-2!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./HelloWorld.vue?vue&type=script&lang=ts */ \"./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/ts-loader/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/components/HelloWorld.vue?vue&type=script&lang=ts\");\n/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, \"default\", function() { return _node_modules_cache_loader_dist_cjs_js_ref_13_0_node_modules_babel_loader_lib_index_js_node_modules_ts_loader_index_js_ref_13_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_HelloWorld_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_0__[\"default\"]; });\n\n/* empty/unused harmony star reexport */ \n\n//# sourceURL=webpack:///./src/components/HelloWorld.vue?");

/***/ }),

/***/ "./src/components/HelloWorld.vue?vue&type=style&index=0&id=469af010&scoped=true&lang=scss":
/*!************************************************************************************************!*\
  !*** ./src/components/HelloWorld.vue?vue&type=style&index=0&id=469af010&scoped=true&lang=scss ***!
  \************************************************************************************************/
/*! no static exports found */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_HelloWorld_vue_vue_type_style_index_0_id_469af010_scoped_true_lang_scss__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! -!../../node_modules/vue-style-loader??ref--8-oneOf-1-0!../../node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!../../node_modules/vue-loader-v16/dist/stylePostLoader.js!../../node_modules/postcss-loader/src??ref--8-oneOf-1-2!../../node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./HelloWorld.vue?vue&type=style&index=0&id=469af010&scoped=true&lang=scss */ \"./node_modules/vue-style-loader/index.js?!./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/sass-loader/dist/cjs.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/components/HelloWorld.vue?vue&type=style&index=0&id=469af010&scoped=true&lang=scss\");\n/* harmony import */ var _node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_HelloWorld_vue_vue_type_style_index_0_id_469af010_scoped_true_lang_scss__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_HelloWorld_vue_vue_type_style_index_0_id_469af010_scoped_true_lang_scss__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony reexport (unknown) */ for(var __WEBPACK_IMPORT_KEY__ in _node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_HelloWorld_vue_vue_type_style_index_0_id_469af010_scoped_true_lang_scss__WEBPACK_IMPORTED_MODULE_0__) if([\"default\"].indexOf(__WEBPACK_IMPORT_KEY__) < 0) (function(key) { __webpack_require__.d(__webpack_exports__, key, function() { return _node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_HelloWorld_vue_vue_type_style_index_0_id_469af010_scoped_true_lang_scss__WEBPACK_IMPORTED_MODULE_0__[key]; }) }(__WEBPACK_IMPORT_KEY__));\n\n\n//# sourceURL=webpack:///./src/components/HelloWorld.vue?");

/***/ }),

/***/ "./src/components/HelloWorld.vue?vue&type=template&id=469af010&scoped=true":
/*!*********************************************************************************!*\
  !*** ./src/components/HelloWorld.vue?vue&type=template&id=469af010&scoped=true ***!
  \*********************************************************************************/
/*! exports provided: render */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _node_modules_cache_loader_dist_cjs_js_ref_12_0_node_modules_babel_loader_lib_index_js_node_modules_vue_loader_v16_dist_templateLoader_js_ref_6_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_HelloWorld_vue_vue_type_template_id_469af010_scoped_true__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! -!../../node_modules/cache-loader/dist/cjs.js??ref--12-0!../../node_modules/babel-loader/lib!../../node_modules/vue-loader-v16/dist/templateLoader.js??ref--6!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./HelloWorld.vue?vue&type=template&id=469af010&scoped=true */ \"./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/vue-loader-v16/dist/templateLoader.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/components/HelloWorld.vue?vue&type=template&id=469af010&scoped=true\");\n/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, \"render\", function() { return _node_modules_cache_loader_dist_cjs_js_ref_12_0_node_modules_babel_loader_lib_index_js_node_modules_vue_loader_v16_dist_templateLoader_js_ref_6_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_HelloWorld_vue_vue_type_template_id_469af010_scoped_true__WEBPACK_IMPORTED_MODULE_0__[\"render\"]; });\n\n\n\n//# sourceURL=webpack:///./src/components/HelloWorld.vue?");

/***/ }),

/***/ "./src/logic/JuneProject.ts":
/*!**********************************!*\
  !*** ./src/logic/JuneProject.ts ***!
  \**********************************/
/*! exports provided: isAgeField, JuneProject */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"isAgeField\", function() { return isAgeField; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"JuneProject\", function() { return JuneProject; });\n/* harmony import */ var core_js_modules_es_symbol_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! core-js/modules/es.symbol.js */ \"./node_modules/core-js/modules/es.symbol.js\");\n/* harmony import */ var core_js_modules_es_symbol_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_symbol_js__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var core_js_modules_es_symbol_description_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! core-js/modules/es.symbol.description.js */ \"./node_modules/core-js/modules/es.symbol.description.js\");\n/* harmony import */ var core_js_modules_es_symbol_description_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_symbol_description_js__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var core_js_modules_es_array_concat_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! core-js/modules/es.array.concat.js */ \"./node_modules/core-js/modules/es.array.concat.js\");\n/* harmony import */ var core_js_modules_es_array_concat_js__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_concat_js__WEBPACK_IMPORTED_MODULE_2__);\n/* harmony import */ var core_js_modules_es_array_filter_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! core-js/modules/es.array.filter.js */ \"./node_modules/core-js/modules/es.array.filter.js\");\n/* harmony import */ var core_js_modules_es_array_filter_js__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_filter_js__WEBPACK_IMPORTED_MODULE_3__);\n/* harmony import */ var core_js_modules_es_array_for_each_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! core-js/modules/es.array.for-each.js */ \"./node_modules/core-js/modules/es.array.for-each.js\");\n/* harmony import */ var core_js_modules_es_array_for_each_js__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_for_each_js__WEBPACK_IMPORTED_MODULE_4__);\n/* harmony import */ var core_js_modules_es_array_from_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! core-js/modules/es.array.from.js */ \"./node_modules/core-js/modules/es.array.from.js\");\n/* harmony import */ var core_js_modules_es_array_from_js__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_from_js__WEBPACK_IMPORTED_MODULE_5__);\n/* harmony import */ var core_js_modules_es_array_join_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! core-js/modules/es.array.join.js */ \"./node_modules/core-js/modules/es.array.join.js\");\n/* harmony import */ var core_js_modules_es_array_join_js__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_join_js__WEBPACK_IMPORTED_MODULE_6__);\n/* harmony import */ var core_js_modules_es_array_map_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! core-js/modules/es.array.map.js */ \"./node_modules/core-js/modules/es.array.map.js\");\n/* harmony import */ var core_js_modules_es_array_map_js__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_map_js__WEBPACK_IMPORTED_MODULE_7__);\n/* harmony import */ var core_js_modules_es_array_reduce_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! core-js/modules/es.array.reduce.js */ \"./node_modules/core-js/modules/es.array.reduce.js\");\n/* harmony import */ var core_js_modules_es_array_reduce_js__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_reduce_js__WEBPACK_IMPORTED_MODULE_8__);\n/* harmony import */ var core_js_modules_es_array_slice_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! core-js/modules/es.array.slice.js */ \"./node_modules/core-js/modules/es.array.slice.js\");\n/* harmony import */ var core_js_modules_es_array_slice_js__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_slice_js__WEBPACK_IMPORTED_MODULE_9__);\n/* harmony import */ var core_js_modules_es_number_constructor_js__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! core-js/modules/es.number.constructor.js */ \"./node_modules/core-js/modules/es.number.constructor.js\");\n/* harmony import */ var core_js_modules_es_number_constructor_js__WEBPACK_IMPORTED_MODULE_10___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_number_constructor_js__WEBPACK_IMPORTED_MODULE_10__);\n/* harmony import */ var core_js_modules_es_object_entries_js__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! core-js/modules/es.object.entries.js */ \"./node_modules/core-js/modules/es.object.entries.js\");\n/* harmony import */ var core_js_modules_es_object_entries_js__WEBPACK_IMPORTED_MODULE_11___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_object_entries_js__WEBPACK_IMPORTED_MODULE_11__);\n/* harmony import */ var core_js_modules_es_object_keys_js__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! core-js/modules/es.object.keys.js */ \"./node_modules/core-js/modules/es.object.keys.js\");\n/* harmony import */ var core_js_modules_es_object_keys_js__WEBPACK_IMPORTED_MODULE_12___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_object_keys_js__WEBPACK_IMPORTED_MODULE_12__);\n/* harmony import */ var core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! core-js/modules/es.object.to-string.js */ \"./node_modules/core-js/modules/es.object.to-string.js\");\n/* harmony import */ var core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_13___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_13__);\n/* harmony import */ var core_js_modules_es_object_values_js__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! core-js/modules/es.object.values.js */ \"./node_modules/core-js/modules/es.object.values.js\");\n/* harmony import */ var core_js_modules_es_object_values_js__WEBPACK_IMPORTED_MODULE_14___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_object_values_js__WEBPACK_IMPORTED_MODULE_14__);\n/* harmony import */ var core_js_modules_es_regexp_exec_js__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! core-js/modules/es.regexp.exec.js */ \"./node_modules/core-js/modules/es.regexp.exec.js\");\n/* harmony import */ var core_js_modules_es_regexp_exec_js__WEBPACK_IMPORTED_MODULE_15___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_regexp_exec_js__WEBPACK_IMPORTED_MODULE_15__);\n/* harmony import */ var core_js_modules_es_set_js__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! core-js/modules/es.set.js */ \"./node_modules/core-js/modules/es.set.js\");\n/* harmony import */ var core_js_modules_es_set_js__WEBPACK_IMPORTED_MODULE_16___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_set_js__WEBPACK_IMPORTED_MODULE_16__);\n/* harmony import */ var core_js_modules_es_string_iterator_js__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! core-js/modules/es.string.iterator.js */ \"./node_modules/core-js/modules/es.string.iterator.js\");\n/* harmony import */ var core_js_modules_es_string_iterator_js__WEBPACK_IMPORTED_MODULE_17___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_string_iterator_js__WEBPACK_IMPORTED_MODULE_17__);\n/* harmony import */ var core_js_modules_es_string_split_js__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! core-js/modules/es.string.split.js */ \"./node_modules/core-js/modules/es.string.split.js\");\n/* harmony import */ var core_js_modules_es_string_split_js__WEBPACK_IMPORTED_MODULE_18___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_string_split_js__WEBPACK_IMPORTED_MODULE_18__);\n/* harmony import */ var core_js_modules_es_string_starts_with_js__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! core-js/modules/es.string.starts-with.js */ \"./node_modules/core-js/modules/es.string.starts-with.js\");\n/* harmony import */ var core_js_modules_es_string_starts_with_js__WEBPACK_IMPORTED_MODULE_19___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_string_starts_with_js__WEBPACK_IMPORTED_MODULE_19__);\n/* harmony import */ var core_js_modules_web_dom_collections_for_each_js__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! core-js/modules/web.dom-collections.for-each.js */ \"./node_modules/core-js/modules/web.dom-collections.for-each.js\");\n/* harmony import */ var core_js_modules_web_dom_collections_for_each_js__WEBPACK_IMPORTED_MODULE_20___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_web_dom_collections_for_each_js__WEBPACK_IMPORTED_MODULE_20__);\n/* harmony import */ var core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! core-js/modules/web.dom-collections.iterator.js */ \"./node_modules/core-js/modules/web.dom-collections.iterator.js\");\n/* harmony import */ var core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_21___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_21__);\n/* harmony import */ var regenerator_runtime_runtime_js__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! regenerator-runtime/runtime.js */ \"./node_modules/regenerator-runtime/runtime.js\");\n/* harmony import */ var regenerator_runtime_runtime_js__WEBPACK_IMPORTED_MODULE_22___default = /*#__PURE__*/__webpack_require__.n(regenerator_runtime_runtime_js__WEBPACK_IMPORTED_MODULE_22__);\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/asyncToGenerator */ \"./node_modules/@babel/runtime/helpers/esm/asyncToGenerator.js\");\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/slicedToArray */ \"./node_modules/@babel/runtime/helpers/esm/slicedToArray.js\");\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ \"./node_modules/@babel/runtime/helpers/esm/classCallCheck.js\");\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_26__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ \"./node_modules/@babel/runtime/helpers/esm/createClass.js\");\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_27__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/construct */ \"./node_modules/@babel/runtime/helpers/esm/construct.js\");\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_28__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toConsumableArray */ \"./node_modules/@babel/runtime/helpers/esm/toConsumableArray.js\");\n/* harmony import */ var d3_fetch__WEBPACK_IMPORTED_MODULE_29__ = __webpack_require__(/*! d3-fetch */ \"./node_modules/d3-fetch/src/index.js\");\n/* harmony import */ var d3_format__WEBPACK_IMPORTED_MODULE_30__ = __webpack_require__(/*! d3-format */ \"./node_modules/d3-format/src/index.js\");\n/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_31__ = __webpack_require__(/*! ramda */ \"./node_modules/ramda/es/index.js\");\n/* harmony import */ var _JuneSimulation__WEBPACK_IMPORTED_MODULE_32__ = __webpack_require__(/*! ./JuneSimulation */ \"./src/logic/JuneSimulation.ts\");\n/* harmony import */ var d3_geo__WEBPACK_IMPORTED_MODULE_33__ = __webpack_require__(/*! d3-geo */ \"./node_modules/d3-geo/src/index.js\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nvar LRU = __webpack_require__(/*! lru-cache */ \"./node_modules/lru-cache/index.js\");\n\nvar basepath = \"demo/projects\";\n\nfunction toDate(day) {\n  var dateArgs = day.split(\"-\").slice(0, 3).map(Number);\n  dateArgs[1] = dateArgs[1] - 1; // Months are 0 indexed. Why?\n\n  return Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_27__[\"default\"])(Date, Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_28__[\"default\"])(dateArgs));\n}\n\nfunction isAgeField(field) {\n  var nums = field.split('_').slice(-2).map(function (x) {\n    return +x;\n  });\n  return ramda__WEBPACK_IMPORTED_MODULE_31__[\"all\"](function (x) {\n    return !isNaN(x);\n  })(nums);\n}\n/**\n * Initialize a class from asynchronous data.\n *\n * Usage (inside async function):\n * >>> const project = await JuneProject.build(project_id)\n * >>> // project logic\n *\n * Usage (inside synchronous function):\n * >>> JuneProject.build(project_id).then(p => {\n * >>>    // project logic...\n * >>> })\n */\n\nvar JuneProject = /*#__PURE__*/function () {\n  // Use `.build(projectName)` to initialize this class\n  function JuneProject(folder, metadata) {\n    Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_25__[\"default\"])(this, JuneProject);\n\n    this._geoData = null;\n    this.folder = folder;\n    this.metadata = metadata;\n    this._runCache = new LRU(50); // Should this number be smaller?\n\n    this._baseCache = new LRU(100); // Shouldn't hold large info\n  }\n\n  Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_26__[\"default\"])(JuneProject, [{\n    key: \"description\",\n    get: function get() {\n      return this.metadata.description;\n    }\n  }, {\n    key: \"all_fields\",\n    get: function get() {\n      return this.metadata.all_fields.sort();\n    }\n  }, {\n    key: \"hasAgeInfo\",\n    get: function get() {\n      return this.ageFieldsAvailable.size > 0;\n    }\n  }, {\n    key: \"hasLocOfInfectionInfo\",\n    get: function get() {\n      return this.locOfInfectionFields.length > 0;\n    }\n  }, {\n    key: \"numeric_fields\",\n    get: function get() {\n      // Every numeric field has a statistic\n      return Object.keys(this.metadata.field_statistics).sort();\n    }\n  }, {\n    key: \"ageFieldsAvailable\",\n    get: function get() {\n      var valid = this.all_fields.filter(isAgeField).map(function (f) {\n        return f.split('_').slice(0, -2).join('_');\n      });\n      return new Set(valid);\n    }\n    /**\n     * Return all fields without age annotations\n     */\n\n  }, {\n    key: \"baseAllFields\",\n    get: function get() {\n      return this.all_fields.filter(function (f) {\n        return !isAgeField(f);\n      });\n    }\n    /**\n     * Return all fields without age annotations\n     */\n\n  }, {\n    key: \"baseNumericFields\",\n    get: function get() {\n      return this.numeric_fields.filter(function (f) {\n        return !isAgeField(f);\n      });\n    }\n  }, {\n    key: \"locOfInfectionFields\",\n    get: function get() {\n      return this.all_fields.filter(function (f) {\n        return f.startsWith(\"n_infections_in\");\n      });\n    }\n  }, {\n    key: \"all_regions\",\n    get: function get() {\n      return this.metadata.all_regions;\n    }\n  }, {\n    key: \"available_regions\",\n    get: function get() {\n      return [\"all\", \"average\"].concat(Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_28__[\"default\"])(this.all_regions));\n    }\n  }, {\n    key: \"all_timestamps\",\n    get: function get() {\n      return this.metadata.all_timestamps;\n    }\n  }, {\n    key: \"all_datetimes\",\n    get: function get() {\n      return this.metadata.all_timestamps.map(function (t) {\n        return new Date(toDate(t));\n      });\n    }\n  }, {\n    key: \"run_parameters\",\n    get: function get() {\n      return this.metadata.run_parameters;\n    }\n    /**\n     * Return a list of all available values for each hyperparametere, lazily\n     */\n\n  }, {\n    key: \"paramList\",\n    get: function get() {\n      var _this = this;\n\n      var key = \"paramList\";\n\n      if (!this._baseCache.has(key)) {\n        function sortAscendingHelper(a, b) {\n          if (typeof a == \"number\" && typeof b == \"number\") return a - b;else if (typeof a == \"string\" && typeof b == \"string\") return a > b ? 1 : -1;else if (typeof a == \"boolean\" && typeof b == \"boolean\") return a > b ? -1 : 1;\n          return 0;\n        }\n\n        var pListed = Object.entries(this.paramSet).map(function (_ref) {\n          var _ref2 = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_24__[\"default\"])(_ref, 2),\n              k = _ref2[0],\n              v = _ref2[1];\n\n          return {\n            name: k,\n            options: Array.from(_this.paramSet[k]).sort(sortAscendingHelper)\n          };\n        });\n\n        this._baseCache.set(key, pListed);\n      }\n\n      return this._baseCache.get(key);\n    }\n  }, {\n    key: \"parameters_varied\",\n    get: function get() {\n      return this.metadata.parameters_varied;\n    }\n  }, {\n    key: \"sorting_parameters\",\n    get: function get() {\n      return [\"ID\"].concat(Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_28__[\"default\"])(this.metadata.parameters_varied));\n    }\n    /**\n     * Get a set of all available values for each hyperparameter, lazily\n     */\n\n  }, {\n    key: \"paramSet\",\n    get: function get() {\n      var key = \"paramSet\";\n\n      if (!this._baseCache.has(key)) {\n        var pset = {};\n        Object.values(this.run_parameters).forEach(function (params) {\n          Object.keys(params).forEach(function (k) {\n            if (k in pset) {\n              pset[k].add(params[k]);\n            } else {\n              pset[k] = new Set([]);\n            }\n          });\n        });\n\n        this._baseCache.set(key, pset);\n      }\n\n      return this._baseCache.get(key);\n    }\n  }, {\n    key: \"runKeys\",\n    get: function get() {\n      return Object.keys(this.metadata.run_parameters);\n    }\n  }, {\n    key: \"path\",\n    get: function get() {\n      return \"\".concat(basepath, \"/\").concat(this.folder);\n    }\n  }, {\n    key: \"fieldExtent\",\n    value: function fieldExtent(fieldNames) {\n      var _this2 = this;\n\n      // Only works if fieldNames length > 0\n      var fieldStats = fieldNames.map(function (f) {\n        return _this2.metadata.field_statistics[f];\n      });\n      return fieldStats.reduce(function (acc, stat) {\n        var newMin = stat.min < acc[0] ? stat.min : acc[0];\n        var newMax = stat.max > acc[1] ? stat.max : acc[1];\n        return [newMin, newMax];\n      }, [Number.POSITIVE_INFINITY, Number.NEGATIVE_INFINITY]);\n    }\n  }, {\n    key: \"geoFile\",\n    value: function () {\n      var _geoFile = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_23__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {\n        return regeneratorRuntime.wrap(function _callee$(_context) {\n          while (1) {\n            switch (_context.prev = _context.next) {\n              case 0:\n                if (this._geoData == null) {\n                  this._geoData = Object(d3_fetch__WEBPACK_IMPORTED_MODULE_29__[\"json\"])(\"\".concat(this.path, \"/sites.geojson\"));\n                }\n\n                return _context.abrupt(\"return\", this._geoData);\n\n              case 2:\n              case \"end\":\n                return _context.stop();\n            }\n          }\n        }, _callee, this);\n      }));\n\n      function geoFile() {\n        return _geoFile.apply(this, arguments);\n      }\n\n      return geoFile;\n    }()\n  }, {\n    key: \"geoProjection\",\n    value: function () {\n      var _geoProjection = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_23__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee2(width, height) {\n        var geoData, goodSSIDs, geoProjection, visibleObject;\n        return regeneratorRuntime.wrap(function _callee2$(_context2) {\n          while (1) {\n            switch (_context2.prev = _context2.next) {\n              case 0:\n                _context2.next = 2;\n                return this.geoFile();\n\n              case 2:\n                geoData = _context2.sent;\n                goodSSIDs = new Set(this.all_regions); // projection:\n\n                geoProjection = Object(d3_geo__WEBPACK_IMPORTED_MODULE_33__[\"geoMercator\"])();\n                visibleObject = {\n                  type: \"FeatureCollection\",\n                  features: geoData.features.filter(function (f) {\n                    return goodSSIDs.has(f.properties.SSID) || goodSSIDs.size === 0;\n                  })\n                };\n                geoProjection.fitSize([width, height], visibleObject);\n                return _context2.abrupt(\"return\", geoProjection);\n\n              case 8:\n              case \"end\":\n                return _context2.stop();\n            }\n          }\n        }, _callee2, this);\n      }));\n\n      function geoProjection(_x, _x2) {\n        return _geoProjection.apply(this, arguments);\n      }\n\n      return geoProjection;\n    }()\n    /**\n     * Choose smart parameter default. Outputs a list of keys for every key, unless `outputSet` specified, in which case we output a set\n     * @param outputSet If true, return object of {[key:string]: Set}\n     */\n\n  }, {\n    key: \"defaultSelected\",\n    value: function () {\n      var _defaultSelected = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_23__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee3() {\n        var outputSet,\n            outputSelected,\n            defaultSim,\n            _args3 = arguments;\n        return regeneratorRuntime.wrap(function _callee3$(_context3) {\n          while (1) {\n            switch (_context3.prev = _context3.next) {\n              case 0:\n                outputSet = _args3.length > 0 && _args3[0] !== undefined ? _args3[0] : false;\n                outputSelected = {}; //@ts-ignore\n\n                defaultSim = this.run_parameters[0];\n                Object.keys(defaultSim).forEach(function (k) {\n                  outputSelected[k] = outputSet ? new Set([defaultSim[k]]) : [defaultSim[k]];\n                });\n                return _context3.abrupt(\"return\", outputSelected);\n\n              case 5:\n              case \"end\":\n                return _context3.stop();\n            }\n          }\n        }, _callee3, this);\n      }));\n\n      function defaultSelected() {\n        return _defaultSelected.apply(this, arguments);\n      }\n\n      return defaultSelected;\n    }()\n    /**\n     * Filter runs that match the key:value pair\n     */\n\n  }, {\n    key: \"filter\",\n    value: function filter(key, value) {\n      return Object.entries(this.run_parameters).filter(function (_ref3) {\n        var _ref4 = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_24__[\"default\"])(_ref3, 2),\n            run_id = _ref4[0],\n            params = _ref4[1];\n\n        return params[key] == value;\n      }).map(function (_ref5) {\n        var _ref6 = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_24__[\"default\"])(_ref5, 2),\n            run_id = _ref6[0],\n            params = _ref6[1];\n\n        return run_id;\n      });\n    }\n    /**\n     * Filter by the data format in 'param selector', {PARAM_NAME: [VALUE1, VALUE2,...]}.\n     * If the filter value of a string is the empty [] or null, assume all parameters are valid\n     * @param filterObj\n     */\n\n  }, {\n    key: \"filterBySelection\",\n    value: function filterBySelection(filterObj) {\n      var _this3 = this;\n\n      var allValidRunKeys = new Set(this.runKeys);\n      var keySets = Object.entries(filterObj).map(function (_ref7) {\n        var _ref8 = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_slicedToArray__WEBPACK_IMPORTED_MODULE_24__[\"default\"])(_ref7, 2),\n            k = _ref8[0],\n            values = _ref8[1];\n\n        // Treat empty arrays as a full set\n        if (values.length == 0) {\n          return allValidRunKeys;\n        }\n\n        var valueRow = values.reduce(function (acc, v) {\n          return [].concat(Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_28__[\"default\"])(acc), Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_28__[\"default\"])(_this3.filter(k, v)));\n        }, []);\n        var valueRowSet = new Set(valueRow);\n        return valueRowSet;\n      });\n      var finalKeys = keySets.reduce(function (acc, runs) {\n        var newRunKeys = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_28__[\"default\"])(runs).filter(function (r) {\n          return acc.has(r);\n        });\n\n        return new Set(newRunKeys);\n      }, allValidRunKeys);\n      return Array.from(finalKeys);\n    }\n  }, {\n    key: \"getRun\",\n    value: function () {\n      var _getRun = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_23__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee4(run_id) {\n        var _this4 = this;\n\n        var f3, fname;\n        return regeneratorRuntime.wrap(function _callee4$(_context4) {\n          while (1) {\n            switch (_context4.prev = _context4.next) {\n              case 0:\n                f3 = Object(d3_format__WEBPACK_IMPORTED_MODULE_30__[\"format\"])('03i');\n                fname = this.path + \"/summary_\".concat(f3(Number(run_id)), \".csv\");\n\n                if (!this._runCache.has(fname)) {\n                  console.log(\"Setting cache of run... -- \", fname); // Add run parameters to object\n\n                  this._runCache.set(fname, Object(d3_fetch__WEBPACK_IMPORTED_MODULE_29__[\"csv\"])(fname).then(function (data) {\n                    var run_parameters = _this4.run_parameters[run_id];\n                    return new _JuneSimulation__WEBPACK_IMPORTED_MODULE_32__[\"JuneSim\"](data, run_parameters, run_id);\n                  }));\n                }\n\n                return _context4.abrupt(\"return\", this._runCache.get(fname));\n\n              case 4:\n              case \"end\":\n                return _context4.stop();\n            }\n          }\n        }, _callee4, this);\n      }));\n\n      function getRun(_x3) {\n        return _getRun.apply(this, arguments);\n      }\n\n      return getRun;\n    }()\n    /**\n     * Get the information from a list of runs.\n     *\n     * @param runIDs List of run keys to fetch. If empty, assume all is desired\n     */\n\n  }, {\n    key: \"getRuns\",\n    value: function () {\n      var _getRuns = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_23__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee5(runIDs) {\n        var _this5 = this;\n\n        return regeneratorRuntime.wrap(function _callee5$(_context5) {\n          while (1) {\n            switch (_context5.prev = _context5.next) {\n              case 0:\n                if (runIDs == null) {\n                  runIDs = this.runKeys;\n                }\n\n                return _context5.abrupt(\"return\", Promise.all(runIDs.map(function (r) {\n                  return _this5.getRun(r);\n                })));\n\n              case 2:\n              case \"end\":\n                return _context5.stop();\n            }\n          }\n        }, _callee5, this);\n      }));\n\n      function getRuns(_x4) {\n        return _getRuns.apply(this, arguments);\n      }\n\n      return getRuns;\n    }()\n  }], [{\n    key: \"build\",\n    value: function () {\n      var _build = Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_asyncToGenerator__WEBPACK_IMPORTED_MODULE_23__[\"default\"])( /*#__PURE__*/regeneratorRuntime.mark(function _callee6(folder) {\n        var projectDir, metadata;\n        return regeneratorRuntime.wrap(function _callee6$(_context6) {\n          while (1) {\n            switch (_context6.prev = _context6.next) {\n              case 0:\n                console.log(\"Building project from folder: \", folder);\n                projectDir = \"\".concat(basepath, \"/\").concat(folder, \"/metadata.json\");\n                _context6.next = 4;\n                return Object(d3_fetch__WEBPACK_IMPORTED_MODULE_29__[\"json\"])(projectDir);\n\n              case 4:\n                metadata = _context6.sent;\n                return _context6.abrupt(\"return\", new JuneProject(folder, metadata));\n\n              case 6:\n              case \"end\":\n                return _context6.stop();\n            }\n          }\n        }, _callee6);\n      }));\n\n      function build(_x5) {\n        return _build.apply(this, arguments);\n      }\n\n      return build;\n    }()\n  }]);\n\n  return JuneProject;\n}();\n\n//# sourceURL=webpack:///./src/logic/JuneProject.ts?");

/***/ }),

/***/ "./src/logic/JuneSimulation.ts":
/*!*************************************!*\
  !*** ./src/logic/JuneSimulation.ts ***!
  \*************************************/
/*! exports provided: JuneSim */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"JuneSim\", function() { return JuneSim; });\n/* harmony import */ var core_js_modules_es_array_filter_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! core-js/modules/es.array.filter.js */ \"./node_modules/core-js/modules/es.array.filter.js\");\n/* harmony import */ var core_js_modules_es_array_filter_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_filter_js__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var core_js_modules_es_array_for_each_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! core-js/modules/es.array.for-each.js */ \"./node_modules/core-js/modules/es.array.for-each.js\");\n/* harmony import */ var core_js_modules_es_array_for_each_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_for_each_js__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var core_js_modules_es_array_from_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! core-js/modules/es.array.from.js */ \"./node_modules/core-js/modules/es.array.from.js\");\n/* harmony import */ var core_js_modules_es_array_from_js__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_from_js__WEBPACK_IMPORTED_MODULE_2__);\n/* harmony import */ var core_js_modules_es_array_join_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! core-js/modules/es.array.join.js */ \"./node_modules/core-js/modules/es.array.join.js\");\n/* harmony import */ var core_js_modules_es_array_join_js__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_join_js__WEBPACK_IMPORTED_MODULE_3__);\n/* harmony import */ var core_js_modules_es_array_map_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! core-js/modules/es.array.map.js */ \"./node_modules/core-js/modules/es.array.map.js\");\n/* harmony import */ var core_js_modules_es_array_map_js__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_map_js__WEBPACK_IMPORTED_MODULE_4__);\n/* harmony import */ var core_js_modules_es_array_slice_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! core-js/modules/es.array.slice.js */ \"./node_modules/core-js/modules/es.array.slice.js\");\n/* harmony import */ var core_js_modules_es_array_slice_js__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_array_slice_js__WEBPACK_IMPORTED_MODULE_5__);\n/* harmony import */ var core_js_modules_es_number_constructor_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! core-js/modules/es.number.constructor.js */ \"./node_modules/core-js/modules/es.number.constructor.js\");\n/* harmony import */ var core_js_modules_es_number_constructor_js__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_number_constructor_js__WEBPACK_IMPORTED_MODULE_6__);\n/* harmony import */ var core_js_modules_es_object_keys_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! core-js/modules/es.object.keys.js */ \"./node_modules/core-js/modules/es.object.keys.js\");\n/* harmony import */ var core_js_modules_es_object_keys_js__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_object_keys_js__WEBPACK_IMPORTED_MODULE_7__);\n/* harmony import */ var core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! core-js/modules/es.object.to-string.js */ \"./node_modules/core-js/modules/es.object.to-string.js\");\n/* harmony import */ var core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_8__);\n/* harmony import */ var core_js_modules_es_regexp_exec_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! core-js/modules/es.regexp.exec.js */ \"./node_modules/core-js/modules/es.regexp.exec.js\");\n/* harmony import */ var core_js_modules_es_regexp_exec_js__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_regexp_exec_js__WEBPACK_IMPORTED_MODULE_9__);\n/* harmony import */ var core_js_modules_es_set_js__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! core-js/modules/es.set.js */ \"./node_modules/core-js/modules/es.set.js\");\n/* harmony import */ var core_js_modules_es_set_js__WEBPACK_IMPORTED_MODULE_10___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_set_js__WEBPACK_IMPORTED_MODULE_10__);\n/* harmony import */ var core_js_modules_es_string_iterator_js__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! core-js/modules/es.string.iterator.js */ \"./node_modules/core-js/modules/es.string.iterator.js\");\n/* harmony import */ var core_js_modules_es_string_iterator_js__WEBPACK_IMPORTED_MODULE_11___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_string_iterator_js__WEBPACK_IMPORTED_MODULE_11__);\n/* harmony import */ var core_js_modules_es_string_split_js__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! core-js/modules/es.string.split.js */ \"./node_modules/core-js/modules/es.string.split.js\");\n/* harmony import */ var core_js_modules_es_string_split_js__WEBPACK_IMPORTED_MODULE_12___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_string_split_js__WEBPACK_IMPORTED_MODULE_12__);\n/* harmony import */ var core_js_modules_es_string_starts_with_js__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! core-js/modules/es.string.starts-with.js */ \"./node_modules/core-js/modules/es.string.starts-with.js\");\n/* harmony import */ var core_js_modules_es_string_starts_with_js__WEBPACK_IMPORTED_MODULE_13___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_string_starts_with_js__WEBPACK_IMPORTED_MODULE_13__);\n/* harmony import */ var core_js_modules_web_dom_collections_for_each_js__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! core-js/modules/web.dom-collections.for-each.js */ \"./node_modules/core-js/modules/web.dom-collections.for-each.js\");\n/* harmony import */ var core_js_modules_web_dom_collections_for_each_js__WEBPACK_IMPORTED_MODULE_14___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_web_dom_collections_for_each_js__WEBPACK_IMPORTED_MODULE_14__);\n/* harmony import */ var core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! core-js/modules/web.dom-collections.iterator.js */ \"./node_modules/core-js/modules/web.dom-collections.iterator.js\");\n/* harmony import */ var core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_15___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_web_dom_collections_iterator_js__WEBPACK_IMPORTED_MODULE_15__);\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/classCallCheck */ \"./node_modules/@babel/runtime/helpers/esm/classCallCheck.js\");\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/createClass */ \"./node_modules/@babel/runtime/helpers/esm/createClass.js\");\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_objectSpread2__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/objectSpread2 */ \"./node_modules/@babel/runtime/helpers/esm/objectSpread2.js\");\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/construct */ \"./node_modules/@babel/runtime/helpers/esm/construct.js\");\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ./node_modules/@babel/runtime/helpers/esm/toConsumableArray */ \"./node_modules/@babel/runtime/helpers/esm/toConsumableArray.js\");\n/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ramda */ \"./node_modules/ramda/es/index.js\");\n/* harmony import */ var _ui_config__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! ./ui_config */ \"./src/logic/ui_config.ts\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nvar stringFields = new Set([\"timestamp\", \"region\", \"date_time\"]);\n/**\n * Convert provided time string into javascript Date\n */\n\nfunction toDate(day) {\n  var dateArgs = day.split(\"-\").slice(0, 3).map(Number);\n  dateArgs[1] = dateArgs[1] - 1; // Months are 0 indexed. Why?\n\n  return Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_construct__WEBPACK_IMPORTED_MODULE_19__[\"default\"])(Date, Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_toConsumableArray__WEBPACK_IMPORTED_MODULE_20__[\"default\"])(dateArgs));\n}\n/**\n * Add the numeric fields of two runs at certain timestepsto create a new run with only numeric fields\n *\n * @param a\n * @param b\n */\n\n\nfunction addPoints(a, b) {\n  var newObj = {};\n  Object.keys(a).filter(function (k) {\n    return !stringFields.has(k);\n  }).forEach(function (k) {\n    //@ts-ignore\n    newObj[k] = +(+a[k] + +b[k]);\n  });\n  return newObj;\n}\n/**\n * Divide a datapoint by a constant\n */\n\n\nfunction dividePointBy(point, x) {\n  var out = {};\n  Object.keys(point).filter(function (k) {\n    return !stringFields.has(k);\n  }).map(function (k) {\n    //@ts-ignore\n    out[k] = point[k] / x;\n  });\n  return out;\n}\n\nfunction getNumericalFields(pt) {\n  var goodKeys = Object.keys(pt).filter(function (k) {\n    return !stringFields.has(k);\n  }); //@ts-ignore\n\n  return ramda__WEBPACK_IMPORTED_MODULE_21__[\"pick\"](goodKeys, pt);\n}\n/**\n * Accumulate a trace whenever a time_stamp is identical\n */\n\n\nfunction aggregateTrace(trace) {\n  var aggRows = {};\n  trace.forEach(function (t) {\n    var kk = t.timestamp;\n    var numericalInfo = getNumericalFields(t);\n\n    if (aggRows[kk] == undefined) {\n      aggRows[kk] = numericalInfo;\n    } else {\n      aggRows[kk] = addPoints(aggRows[kk], numericalInfo);\n    }\n  }); // Convert aggRows back into an expected sequence of data\n\n  var aggTrace = Object.keys(aggRows).map(function (k) {\n    return Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_objectSpread2__WEBPACK_IMPORTED_MODULE_18__[\"default\"])(Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_objectSpread2__WEBPACK_IMPORTED_MODULE_18__[\"default\"])({}, aggRows[k]), {}, {\n      timestamp: k,\n      date_time: new Date(toDate(k))\n    });\n  }); // Also has time_stamp and date_time\n\n  return aggTrace;\n}\n/**\n * Wrapper around each dataset in a project.\n */\n\n\nvar JuneSim = /*#__PURE__*/function () {\n  function JuneSim(values, params, runId) {\n    Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_classCallCheck__WEBPACK_IMPORTED_MODULE_16__[\"default\"])(this, JuneSim);\n\n    this.values = values.map(function (row) {\n      var newRow = Object.assign({}, row);\n      newRow.date_time = toDate(row.timestamp);\n      return newRow;\n    });\n    this.run_parameters = params;\n    this.runId = runId;\n  }\n\n  Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_createClass__WEBPACK_IMPORTED_MODULE_17__[\"default\"])(JuneSim, [{\n    key: \"allRegions\",\n    get: function get() {\n      return Array.from(new Set(this.values.map(function (v) {\n        return v.region;\n      })));\n    }\n  }, {\n    key: \"nRegions\",\n    get: function get() {\n      return this.allRegions.length;\n    }\n  }, {\n    key: \"ageBinKeys\",\n    value: function ageBinKeys() {\n      var keyPrefix = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : \"currently_susceptible_\";\n      var vi = this.values[0]; // Assume value exists\n\n      var susBins = Object.keys(vi).filter(function (k) {\n        return k.startsWith(keyPrefix);\n      });\n      var ageBins = susBins.map(function (k) {\n        return k.split(\"_\").slice(-2).join(\"_\");\n      });\n      return ageBins;\n    }\n  }, {\n    key: \"ageBinCounts\",\n    value: function ageBinCounts(trace) {\n      var vi = trace[0];\n      var ageBins = this.ageBinKeys();\n      var susBins = ageBins.map(function (age) {\n        return \"currently_susceptible_\".concat(age);\n      });\n      var infBins = ageBins.map(function (age) {\n        return \"currently_infected_\".concat(age);\n      }); //@ts-ignore\n\n      var ageCounts = ramda__WEBPACK_IMPORTED_MODULE_21__[\"zip\"](susBins, infBins).map(function (k) {\n        return +vi[k[0]] + +vi[k[1]];\n      });\n      var out = ramda__WEBPACK_IMPORTED_MODULE_21__[\"zipObj\"](ageBins, ageCounts);\n      return out;\n    }\n  }, {\n    key: \"numericFieldsAvailable\",\n    value: function numericFieldsAvailable() {\n      return Object.keys(this.values[0]).filter(function (key) {\n        return !stringFields.has(key);\n      });\n    }\n    /**\n     * Fetch all available regions\n     * @param basicSet Parameters to add to available regions\n     */\n\n  }, {\n    key: \"regionsAvailable\",\n    value: function regionsAvailable() {\n      var basicSet = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [\"all\", \"average\"];\n      var regionSet = new Set(this.values.map(function (v) {\n        return v.region;\n      }));\n      basicSet.forEach(function (s) {\n        return regionSet.add(s);\n      });\n      return Array.from(regionSet);\n    }\n  }, {\n    key: \"aggregateByAllRegions\",\n    value: function aggregateByAllRegions() {\n      return aggregateTrace(this.values);\n    }\n  }, {\n    key: \"aggregateByAvgRegion\",\n    value: function aggregateByAvgRegion() {\n      var _this = this;\n\n      var trace = aggregateTrace(this.values);\n      return trace.map(function (t) {\n        return Object(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_babel_runtime_helpers_esm_objectSpread2__WEBPACK_IMPORTED_MODULE_18__[\"default\"])({\n          timestamp: t.timestamp,\n          date_time: t.date_time\n        }, dividePointBy(t, _this.nRegions));\n      });\n    }\n  }, {\n    key: \"aggregateByRegion\",\n    value: function aggregateByRegion(region) {\n      if (region == \"all\") {\n        return this.aggregateByAllRegions();\n      } else if (region == \"average\") {\n        return this.aggregateByAvgRegion();\n      }\n\n      return this.values.filter(function (v) {\n        return v.region == region;\n      });\n    }\n    /**\n     * Extract the trace corresponding to a particular region and field\n     *\n     * @param region Which region to filter by, including \"average\" and \"all\"\n     * @param field Which field to extract\n     */\n\n  }, {\n    key: \"getTraceWithField\",\n    value: function getTraceWithField(region, field) {\n      var procRun = function procRun(v, i) {\n        if (_ui_config__WEBPACK_IMPORTED_MODULE_22__[\"default\"].showRealDate) {\n          //@ts-ignore\n          return {\n            x: v.date_time,\n            y: +v[field]\n          };\n        } //@ts-ignore\n\n\n        return {\n          x: i,\n          y: +v[field]\n        };\n      };\n\n      if (region == \"all\") {\n        return this.aggregateByAllRegions().map(procRun);\n      } else if (region == \"average\") {\n        return this.aggregateByAvgRegion().map(procRun);\n      }\n\n      return this.values.filter(function (v) {\n        return v.region == region;\n      }).map(procRun);\n    }\n  }]);\n\n  return JuneSim;\n}();\n\n//# sourceURL=webpack:///./src/logic/JuneSimulation.ts?");

/***/ }),

/***/ "./src/logic/display.ts":
/*!******************************!*\
  !*** ./src/logic/display.ts ***!
  \******************************/
/*! exports provided: formatValDisplay, colorway, lineColor */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"formatValDisplay\", function() { return formatValDisplay; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"colorway\", function() { return colorway; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"lineColor\", function() { return lineColor; });\n/* harmony import */ var core_js_modules_es_number_to_fixed_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! core-js/modules/es.number.to-fixed.js */ \"./node_modules/core-js/modules/es.number.to-fixed.js\");\n/* harmony import */ var core_js_modules_es_number_to_fixed_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_number_to_fixed_js__WEBPACK_IMPORTED_MODULE_0__);\n\nfunction formatValDisplay(val) {\n  if (typeof val == \"number\") return val.toFixed(2);\n  return val;\n}\n/**\n * The default color cycle for Plotly. Can be customized to any length and any colors.\n */\n\nvar colorway = [\"#00AEEF\", \"#9B4531\", \"#FFB100\", \"#CF8236\", \"#007BE0\", \"#665E1E\", \"#487D7C\", \"#00447C\", \"#CF5C42\", \"#5D6263\"];\n/**\n * Color a line according to an index\n */\n\nvar lineColor = function lineColor(i) {\n  return colorway[i % colorway.length];\n};\n\n//# sourceURL=webpack:///./src/logic/display.ts?");

/***/ }),

/***/ "./src/logic/ui_config.ts":
/*!********************************!*\
  !*** ./src/logic/ui_config.ts ***!
  \********************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony default export */ __webpack_exports__[\"default\"] = ({\n  normalizeAgeBins: true,\n  showRealDate: false\n});\n\n//# sourceURL=webpack:///./src/logic/ui_config.ts?");

/***/ }),

/***/ "./src/main.ts":
/*!*********************!*\
  !*** ./src/main.ts ***!
  \*********************/
/*! no exports provided */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_core_js_modules_es_array_iterator_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./node_modules/core-js/modules/es.array.iterator.js */ \"./node_modules/core-js/modules/es.array.iterator.js\");\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_core_js_modules_es_array_iterator_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_core_js_modules_es_array_iterator_js__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_core_js_modules_es_promise_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./node_modules/core-js/modules/es.promise.js */ \"./node_modules/core-js/modules/es.promise.js\");\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_core_js_modules_es_promise_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_core_js_modules_es_promise_js__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_core_js_modules_es_object_assign_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./node_modules/core-js/modules/es.object.assign.js */ \"./node_modules/core-js/modules/es.object.assign.js\");\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_core_js_modules_es_object_assign_js__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_core_js_modules_es_object_assign_js__WEBPACK_IMPORTED_MODULE_2__);\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_core_js_modules_es_promise_finally_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./node_modules/core-js/modules/es.promise.finally.js */ \"./node_modules/core-js/modules/es.promise.finally.js\");\n/* harmony import */ var _Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_core_js_modules_es_promise_finally_js__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(_Users_benjamin_hoover_ibm_com_Projects_JUNE_vis_junevis_client_node_modules_core_js_modules_es_promise_finally_js__WEBPACK_IMPORTED_MODULE_3__);\n/* harmony import */ var vue__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! vue */ \"./node_modules/vue/dist/vue.runtime.esm-bundler.js\");\n/* harmony import */ var _App_vue__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./App.vue */ \"./src/App.vue\");\n/* harmony import */ var _router__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./router */ \"./src/router/index.ts\");\n\n\n\n\n\n\n // @ts-ignore\n\nObject(vue__WEBPACK_IMPORTED_MODULE_4__[\"createApp\"])(_App_vue__WEBPACK_IMPORTED_MODULE_5__[\"default\"]).use(_router__WEBPACK_IMPORTED_MODULE_6__[\"default\"]).mount('#app');\n\n//# sourceURL=webpack:///./src/main.ts?");

/***/ }),

/***/ "./src/router/index.ts":
/*!*****************************!*\
  !*** ./src/router/index.ts ***!
  \*****************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! core-js/modules/es.object.to-string.js */ \"./node_modules/core-js/modules/es.object.to-string.js\");\n/* harmony import */ var core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_object_to_string_js__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var vue_router__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! vue-router */ \"./node_modules/vue-router/dist/vue-router.esm-bundler.js\");\n/* harmony import */ var _views_Intro_vue__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @/views/Intro.vue */ \"./src/views/Intro.vue\");\n/* harmony import */ var _views_CompareGeos_vue__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! @/views/CompareGeos.vue */ \"./src/views/CompareGeos.vue\");\n\n\n\n\nvar routes = [{\n  path: '/',\n  name: 'Home',\n  component: function component() {\n    return _views_Intro_vue__WEBPACK_IMPORTED_MODULE_2__[\"default\"];\n  }\n}, {\n  path: '/:projectId/exploreRuns',\n  name: 'Explore Runs',\n  // route level code-splitting\n  // this generates a separate chunk (about.[hash].js) for this route\n  // which is lazy-loaded when the route is visited.\n  component: function component() {\n    return Promise.all(/*! import() | compareRuns */[__webpack_require__.e(\"compareRuns~geoRun\"), __webpack_require__.e(\"compareRuns\")]).then(__webpack_require__.bind(null, /*! ../views/CompareRuns.vue */ \"./src/views/CompareRuns.vue\"));\n  },\n  props: true\n}, {\n  path: '/:projectId/runDetails/:run1Id/:run2Id?',\n  name: 'Compare Runs',\n  // route level code-splitting\n  // this generates a separate chunk (about.[hash].js) for this route\n  // which is lazy-loaded when the route is visited.\n  component: function component() {\n    return Promise.all(/*! import() | compareRuns */[__webpack_require__.e(\"compareRuns~geoRun\"), __webpack_require__.e(\"compareRuns\")]).then(__webpack_require__.bind(null, /*! ../views/RunDetails.vue */ \"./src/views/RunDetails.vue\"));\n  },\n  props: true\n}, {\n  path: '/:projectId/compareGeos',\n  name: 'Compare Geographical Regions',\n  component: function component() {\n    return _views_CompareGeos_vue__WEBPACK_IMPORTED_MODULE_3__[\"default\"];\n  },\n  props: true\n}, {\n  path: '/geoRun/:projectId?/:runId?/:dim?',\n  name: 'geoRun',\n  component: function component() {\n    return Promise.all(/*! import() | geoRun */[__webpack_require__.e(\"compareRuns~geoRun\"), __webpack_require__.e(\"geoRun\")]).then(__webpack_require__.bind(null, /*! ../views/GeoRun.vue */ \"./src/views/GeoRun.vue\"));\n  }\n}, {\n  path: '/geoTest',\n  name: 'geoTest',\n  component: function component() {\n    return __webpack_require__.e(/*! import() */ 0).then(__webpack_require__.bind(null, /*! ../views/TestMap.vue */ \"./src/views/TestMap.vue\"));\n  }\n}];\nvar router = Object(vue_router__WEBPACK_IMPORTED_MODULE_1__[\"createRouter\"])({\n  history: Object(vue_router__WEBPACK_IMPORTED_MODULE_1__[\"createWebHashHistory\"])(),\n  routes: routes\n});\n/* harmony default export */ __webpack_exports__[\"default\"] = (router);\n\n//# sourceURL=webpack:///./src/router/index.ts?");

/***/ }),

/***/ "./src/utils/cacher.ts":
/*!*****************************!*\
  !*** ./src/utils/cacher.ts ***!
  \*****************************/
/*! exports provided: memoize */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"memoize\", function() { return memoize; });\n// Use require syntax. import * doesn't work with TS\nvar LRU = __webpack_require__(/*! lru-cache */ \"./node_modules/lru-cache/index.js\");\n/**\n * Memoize an arbitrary function\n *\n * @param fn Function to memoize the result of\n */\n\n\nfunction memoize(fn) {\n  var cache = new LRU(100); // Sets max size\n\n  return function () {\n    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {\n      args[_key] = arguments[_key];\n    }\n\n    var key = JSON.stringify(args);\n\n    if (cache.has(key)) {\n      return cache.get(key);\n    }\n\n    var result = fn.apply(void 0, args);\n    cache.set(key, result);\n    return result;\n  };\n}\n\n//# sourceURL=webpack:///./src/utils/cacher.ts?");

/***/ }),

/***/ "./src/views/CompareGeos.vue":
/*!***********************************!*\
  !*** ./src/views/CompareGeos.vue ***!
  \***********************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _CompareGeos_vue_vue_type_template_id_64742406_scoped_true__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./CompareGeos.vue?vue&type=template&id=64742406&scoped=true */ \"./src/views/CompareGeos.vue?vue&type=template&id=64742406&scoped=true\");\n/* harmony import */ var _CompareGeos_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./CompareGeos.vue?vue&type=script&lang=ts */ \"./src/views/CompareGeos.vue?vue&type=script&lang=ts\");\n/* empty/unused harmony star reexport *//* harmony import */ var _CompareGeos_vue_vue_type_style_index_0_id_64742406_scoped_true_lang_scss__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./CompareGeos.vue?vue&type=style&index=0&id=64742406&scoped=true&lang=scss */ \"./src/views/CompareGeos.vue?vue&type=style&index=0&id=64742406&scoped=true&lang=scss\");\n\n\n\n\n\n_CompareGeos_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"].render = _CompareGeos_vue_vue_type_template_id_64742406_scoped_true__WEBPACK_IMPORTED_MODULE_0__[\"render\"]\n_CompareGeos_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"].__scopeId = \"data-v-64742406\"\n/* hot reload */\nif (false) {}\n\n_CompareGeos_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"].__file = \"src/views/CompareGeos.vue\"\n\n/* harmony default export */ __webpack_exports__[\"default\"] = (_CompareGeos_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"]);\n\n//# sourceURL=webpack:///./src/views/CompareGeos.vue?");

/***/ }),

/***/ "./src/views/CompareGeos.vue?vue&type=script&lang=ts":
/*!***********************************************************!*\
  !*** ./src/views/CompareGeos.vue?vue&type=script&lang=ts ***!
  \***********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _node_modules_cache_loader_dist_cjs_js_ref_13_0_node_modules_babel_loader_lib_index_js_node_modules_ts_loader_index_js_ref_13_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_CompareGeos_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! -!../../node_modules/cache-loader/dist/cjs.js??ref--13-0!../../node_modules/babel-loader/lib!../../node_modules/ts-loader??ref--13-2!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./CompareGeos.vue?vue&type=script&lang=ts */ \"./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/ts-loader/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/CompareGeos.vue?vue&type=script&lang=ts\");\n/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, \"default\", function() { return _node_modules_cache_loader_dist_cjs_js_ref_13_0_node_modules_babel_loader_lib_index_js_node_modules_ts_loader_index_js_ref_13_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_CompareGeos_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_0__[\"default\"]; });\n\n/* empty/unused harmony star reexport */ \n\n//# sourceURL=webpack:///./src/views/CompareGeos.vue?");

/***/ }),

/***/ "./src/views/CompareGeos.vue?vue&type=style&index=0&id=64742406&scoped=true&lang=scss":
/*!********************************************************************************************!*\
  !*** ./src/views/CompareGeos.vue?vue&type=style&index=0&id=64742406&scoped=true&lang=scss ***!
  \********************************************************************************************/
/*! no static exports found */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_CompareGeos_vue_vue_type_style_index_0_id_64742406_scoped_true_lang_scss__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! -!../../node_modules/vue-style-loader??ref--8-oneOf-1-0!../../node_modules/css-loader/dist/cjs.js??ref--8-oneOf-1-1!../../node_modules/vue-loader-v16/dist/stylePostLoader.js!../../node_modules/postcss-loader/src??ref--8-oneOf-1-2!../../node_modules/sass-loader/dist/cjs.js??ref--8-oneOf-1-3!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./CompareGeos.vue?vue&type=style&index=0&id=64742406&scoped=true&lang=scss */ \"./node_modules/vue-style-loader/index.js?!./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/sass-loader/dist/cjs.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/CompareGeos.vue?vue&type=style&index=0&id=64742406&scoped=true&lang=scss\");\n/* harmony import */ var _node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_CompareGeos_vue_vue_type_style_index_0_id_64742406_scoped_true_lang_scss__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_CompareGeos_vue_vue_type_style_index_0_id_64742406_scoped_true_lang_scss__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony reexport (unknown) */ for(var __WEBPACK_IMPORT_KEY__ in _node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_CompareGeos_vue_vue_type_style_index_0_id_64742406_scoped_true_lang_scss__WEBPACK_IMPORTED_MODULE_0__) if([\"default\"].indexOf(__WEBPACK_IMPORT_KEY__) < 0) (function(key) { __webpack_require__.d(__webpack_exports__, key, function() { return _node_modules_vue_style_loader_index_js_ref_8_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_8_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_8_oneOf_1_2_node_modules_sass_loader_dist_cjs_js_ref_8_oneOf_1_3_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_CompareGeos_vue_vue_type_style_index_0_id_64742406_scoped_true_lang_scss__WEBPACK_IMPORTED_MODULE_0__[key]; }) }(__WEBPACK_IMPORT_KEY__));\n\n\n//# sourceURL=webpack:///./src/views/CompareGeos.vue?");

/***/ }),

/***/ "./src/views/CompareGeos.vue?vue&type=template&id=64742406&scoped=true":
/*!*****************************************************************************!*\
  !*** ./src/views/CompareGeos.vue?vue&type=template&id=64742406&scoped=true ***!
  \*****************************************************************************/
/*! exports provided: render */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _node_modules_cache_loader_dist_cjs_js_ref_12_0_node_modules_babel_loader_lib_index_js_node_modules_vue_loader_v16_dist_templateLoader_js_ref_6_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_CompareGeos_vue_vue_type_template_id_64742406_scoped_true__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! -!../../node_modules/cache-loader/dist/cjs.js??ref--12-0!../../node_modules/babel-loader/lib!../../node_modules/vue-loader-v16/dist/templateLoader.js??ref--6!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./CompareGeos.vue?vue&type=template&id=64742406&scoped=true */ \"./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/vue-loader-v16/dist/templateLoader.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/CompareGeos.vue?vue&type=template&id=64742406&scoped=true\");\n/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, \"render\", function() { return _node_modules_cache_loader_dist_cjs_js_ref_12_0_node_modules_babel_loader_lib_index_js_node_modules_vue_loader_v16_dist_templateLoader_js_ref_6_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_CompareGeos_vue_vue_type_template_id_64742406_scoped_true__WEBPACK_IMPORTED_MODULE_0__[\"render\"]; });\n\n\n\n//# sourceURL=webpack:///./src/views/CompareGeos.vue?");

/***/ }),

/***/ "./src/views/Intro.vue":
/*!*****************************!*\
  !*** ./src/views/Intro.vue ***!
  \*****************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _Intro_vue_vue_type_template_id_f12fd2bc_scoped_true__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./Intro.vue?vue&type=template&id=f12fd2bc&scoped=true */ \"./src/views/Intro.vue?vue&type=template&id=f12fd2bc&scoped=true\");\n/* harmony import */ var _Intro_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./Intro.vue?vue&type=script&lang=ts */ \"./src/views/Intro.vue?vue&type=script&lang=ts\");\n/* empty/unused harmony star reexport *//* harmony import */ var _Intro_vue_vue_type_style_index_0_id_f12fd2bc_scoped_true_lang_css__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./Intro.vue?vue&type=style&index=0&id=f12fd2bc&scoped=true&lang=css */ \"./src/views/Intro.vue?vue&type=style&index=0&id=f12fd2bc&scoped=true&lang=css\");\n\n\n\n\n\n_Intro_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"].render = _Intro_vue_vue_type_template_id_f12fd2bc_scoped_true__WEBPACK_IMPORTED_MODULE_0__[\"render\"]\n_Intro_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"].__scopeId = \"data-v-f12fd2bc\"\n/* hot reload */\nif (false) {}\n\n_Intro_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"].__file = \"src/views/Intro.vue\"\n\n/* harmony default export */ __webpack_exports__[\"default\"] = (_Intro_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_1__[\"default\"]);\n\n//# sourceURL=webpack:///./src/views/Intro.vue?");

/***/ }),

/***/ "./src/views/Intro.vue?vue&type=script&lang=ts":
/*!*****************************************************!*\
  !*** ./src/views/Intro.vue?vue&type=script&lang=ts ***!
  \*****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _node_modules_cache_loader_dist_cjs_js_ref_13_0_node_modules_babel_loader_lib_index_js_node_modules_ts_loader_index_js_ref_13_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_Intro_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! -!../../node_modules/cache-loader/dist/cjs.js??ref--13-0!../../node_modules/babel-loader/lib!../../node_modules/ts-loader??ref--13-2!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./Intro.vue?vue&type=script&lang=ts */ \"./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/ts-loader/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/Intro.vue?vue&type=script&lang=ts\");\n/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, \"default\", function() { return _node_modules_cache_loader_dist_cjs_js_ref_13_0_node_modules_babel_loader_lib_index_js_node_modules_ts_loader_index_js_ref_13_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_Intro_vue_vue_type_script_lang_ts__WEBPACK_IMPORTED_MODULE_0__[\"default\"]; });\n\n/* empty/unused harmony star reexport */ \n\n//# sourceURL=webpack:///./src/views/Intro.vue?");

/***/ }),

/***/ "./src/views/Intro.vue?vue&type=style&index=0&id=f12fd2bc&scoped=true&lang=css":
/*!*************************************************************************************!*\
  !*** ./src/views/Intro.vue?vue&type=style&index=0&id=f12fd2bc&scoped=true&lang=css ***!
  \*************************************************************************************/
/*! no static exports found */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _node_modules_vue_style_loader_index_js_ref_6_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_6_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_6_oneOf_1_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_Intro_vue_vue_type_style_index_0_id_f12fd2bc_scoped_true_lang_css__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! -!../../node_modules/vue-style-loader??ref--6-oneOf-1-0!../../node_modules/css-loader/dist/cjs.js??ref--6-oneOf-1-1!../../node_modules/vue-loader-v16/dist/stylePostLoader.js!../../node_modules/postcss-loader/src??ref--6-oneOf-1-2!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./Intro.vue?vue&type=style&index=0&id=f12fd2bc&scoped=true&lang=css */ \"./node_modules/vue-style-loader/index.js?!./node_modules/css-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/stylePostLoader.js!./node_modules/postcss-loader/src/index.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/Intro.vue?vue&type=style&index=0&id=f12fd2bc&scoped=true&lang=css\");\n/* harmony import */ var _node_modules_vue_style_loader_index_js_ref_6_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_6_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_6_oneOf_1_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_Intro_vue_vue_type_style_index_0_id_f12fd2bc_scoped_true_lang_css__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_vue_style_loader_index_js_ref_6_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_6_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_6_oneOf_1_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_Intro_vue_vue_type_style_index_0_id_f12fd2bc_scoped_true_lang_css__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony reexport (unknown) */ for(var __WEBPACK_IMPORT_KEY__ in _node_modules_vue_style_loader_index_js_ref_6_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_6_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_6_oneOf_1_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_Intro_vue_vue_type_style_index_0_id_f12fd2bc_scoped_true_lang_css__WEBPACK_IMPORTED_MODULE_0__) if([\"default\"].indexOf(__WEBPACK_IMPORT_KEY__) < 0) (function(key) { __webpack_require__.d(__webpack_exports__, key, function() { return _node_modules_vue_style_loader_index_js_ref_6_oneOf_1_0_node_modules_css_loader_dist_cjs_js_ref_6_oneOf_1_1_node_modules_vue_loader_v16_dist_stylePostLoader_js_node_modules_postcss_loader_src_index_js_ref_6_oneOf_1_2_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_Intro_vue_vue_type_style_index_0_id_f12fd2bc_scoped_true_lang_css__WEBPACK_IMPORTED_MODULE_0__[key]; }) }(__WEBPACK_IMPORT_KEY__));\n\n\n//# sourceURL=webpack:///./src/views/Intro.vue?");

/***/ }),

/***/ "./src/views/Intro.vue?vue&type=template&id=f12fd2bc&scoped=true":
/*!***********************************************************************!*\
  !*** ./src/views/Intro.vue?vue&type=template&id=f12fd2bc&scoped=true ***!
  \***********************************************************************/
/*! exports provided: render */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _node_modules_cache_loader_dist_cjs_js_ref_12_0_node_modules_babel_loader_lib_index_js_node_modules_vue_loader_v16_dist_templateLoader_js_ref_6_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_Intro_vue_vue_type_template_id_f12fd2bc_scoped_true__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! -!../../node_modules/cache-loader/dist/cjs.js??ref--12-0!../../node_modules/babel-loader/lib!../../node_modules/vue-loader-v16/dist/templateLoader.js??ref--6!../../node_modules/cache-loader/dist/cjs.js??ref--0-0!../../node_modules/vue-loader-v16/dist??ref--0-1!./Intro.vue?vue&type=template&id=f12fd2bc&scoped=true */ \"./node_modules/cache-loader/dist/cjs.js?!./node_modules/babel-loader/lib/index.js!./node_modules/vue-loader-v16/dist/templateLoader.js?!./node_modules/cache-loader/dist/cjs.js?!./node_modules/vue-loader-v16/dist/index.js?!./src/views/Intro.vue?vue&type=template&id=f12fd2bc&scoped=true\");\n/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, \"render\", function() { return _node_modules_cache_loader_dist_cjs_js_ref_12_0_node_modules_babel_loader_lib_index_js_node_modules_vue_loader_v16_dist_templateLoader_js_ref_6_node_modules_cache_loader_dist_cjs_js_ref_0_0_node_modules_vue_loader_v16_dist_index_js_ref_0_1_Intro_vue_vue_type_template_id_f12fd2bc_scoped_true__WEBPACK_IMPORTED_MODULE_0__[\"render\"]; });\n\n\n\n//# sourceURL=webpack:///./src/views/Intro.vue?");

/***/ }),

/***/ 0:
/*!***************************!*\
  !*** multi ./src/main.ts ***!
  \***************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("module.exports = __webpack_require__(/*! ./src/main.ts */\"./src/main.ts\");\n\n\n//# sourceURL=webpack:///multi_./src/main.ts?");

/***/ })

/******/ });